---
url: https://www.normattiva.it/uri-res/N2Ls?urn:nir:stato:decreto.legislativo:1997-07-09;241
url_xml: https://www.normattiva.it/do/atto/caricaAKN?dataGU=19970728&codiceRedaz=097G0277&dataVigenza=20251104
dataGU: 19970728
codiceRedaz: 097G0277
dataVigenza: 20251104
---

# Norme di semplificazione degli adempimenti dei contribuenti in sede di dichiarazione dei redditi e dell'imposta sul valore aggiunto,
nonche' di modernizzazione del sistema di gestione delle
dichiarazioni.

IL PRESIDENTE DELLA REPUBBLICA

Visti gli articoli 76 e 87 della Costituzione;

Visto l'articolo 3, comma 134, della legge 23 dicembre 1996, n. 662, recante delega al Governo per l'emanazione di uno o piu' decreti legislativi contenenti disposizioni volte a semplificare gli adempimenti dei contribuenti, a modernizzare il sistema di gestione delle dichiarazioni, in modo da assicurare la gestione unitaria delle posizioni dei singoli contribuenti;

Vista la preliminare deliberazione del Consiglio dei Ministri, adottata nella riunione del 16 maggio 1997;

Visto il parere della commissione parlamentare istituita dall'articolo 3, comma 13, della citata legge n. 662 del 1996, reso in data 25 giugno 1997, in applicazione del comma 15 del predetto articolo 3;

Tenuto conto che, in applicazione del comma 15 del medesimo articolo 3, e' stata concessa la proroga di venti giorni per l'adozione del predetto parere e che, conseguentemente, a norma del comma 16 risulta per un uguale periodo prorogato il termine per l'esercizio della delega;

Vista la deliberazione del Consiglio dei Ministri, adottata nella riunione del 27 giugno 1997;

Sulla proposta del Ministro delle finanze, di concerto con il Ministro del tesoro;

Emana il seguente decreto legislativo:

## DISPOSIZIONI IN MATERIA DI DICHIARAZIONI ANNUALI DEI REDDITI E DELLA IMPOSTA SUL VALORE AGGIUNTO

### Art. 1. - (Certificazioni e documenti riguardanti la dichiarazione delle persone fisiche)

1. L'articolo 3 del decreto del Presidente della Repubblica 29 settembre 1973, n. 600, riguardante l'accertamento delle imposte sui redditi e' sostituito dal seguente: "Art. 3 (Certificazioni e documenti riguardanti la dichiarazione delle persone fisiche) - 1. Le persone fisiche che esercitano imprese commerciali ai sensi dell'articolo 51 del testo unico delle imposte sui redditi, approvato con decreto del Presidente della Repubblica 22 dicembre 1986, n. 917, anche se non obbligati da altre norme devono redigere e conservare, per il periodo indicato nell'articolo 22, il bilancio, composto dallo stato patrimoniale e dal conto dei profitti e delle perdite, relativo al periodo d'imposta. I ricavi, i costi, le rimanenze e gli altri elementi necessari, secondo le disposizioni del capo VI del titolo I del citato testo unico, per la determinazione del reddito d'impresa devono essere indicati in apposito prospetto, qualora non risultanti dal bilancio. 2. Le disposizioni del comma 1 non si applicano ai soggetti che, ammessi a regimi contabili semplificati, non hanno optato per il regime di contabilita' ordinaria. 3. I contribuenti devono conservare, per il periodo previsto dall'articolo 43, le certificazioni dei sostituti di imposta, nonche' i documenti probatori dei crediti di imposta, dei versamenti eseguiti con riferimento alla dichiarazione dei redditi e degli oneri deducibili o detraibili ed ogni altro documento previsto dal decreto di cui all'articolo 8. Le certificazioni ed i documenti devono essere esibiti o trasmessi, su richiesta, all'ufficio competente.". Avvertenza: Il testo delle note qui pubblicato e' stato redatto ai sensi dell'art. 10, comma 3, del testo unico delle disposizioni sulla promulgazione delle leggi, sull'emanazione dei decreti del Presidente della Repubblica e sulle pubblicazioni ufficiali della Repubblica italiana, approvato con D.P.R. 28 dicembre 1985, n. 1092, al solo fine di facilitare la lettura delle disposioni di legge alle quali e' operato il rinvio. Restano invariati il valore e l'efficacia degli atti legislativi qui trascritti.

### Art. 2. - (Certificazioni e documentazioni riguardanti la dichiarazione dei soggetti all'imposta sul reddito delle persone giuridiche)

1. L'articolo 5 del decreto del Presidente della Repubblica 29 settembre 1973, n. 600, e' sostituito dal seguente: "Art. 5 (Certificazioni e documentazioni riguardanti la dichiarazione dei soggetti all'imposta sul reddito delle persone giuridiche) - 1. I soggetti all'imposta sul reddito delle persone giuridiche devono conservare, per il periodo indicato nell'articolo 22, il bilancio o il rendiconto, nonche' i relativi verbali e relazioni, cui sono obbligati dal codice civile, da leggi speciali o dallo statuto. I ricavi, i costi, le rimanenze e gli altri elementi necessari, secondo le disposizioni del capo VI del titolo I del testo unico delle imposte sui redditi approvato con decreto del Presidente della Repubblica 22 dicembre 1986, n. 917, per la determinazione dell'imponibile devono essere indicati in apposito prospetto, qualora non risultanti dal bilancio o dal rendiconto. 2. Gli enti indicati alla lettera c) del comma 1 dell'articolo 87 del testo unico delle imposte sui redditi, approvato con decreto del Presidente della Repubblica 22 dicembre 1986, n. 917, devono conservare il bilancio relativo alle attivita' commerciali eventualmente esercitate. La disposizione non si applica agli enti che, ammessi a regimi contabili semplificati, non hanno optato per il regime ordinario. 3. Le societa' e gli enti indicati alla lettera d) del comma 1 dell'articolo 87 del testo unico delle imposte sui redditi, approvato con decreto del Presidente della Repubblica 22 dicembre 1986, n. 917, devono conservare il bilancio relativo alle attivita' esercitate nel territorio dello Stato mediante stabili organizzazioni. Non sono obbligati alla conservazione del bilancio le societa' semplici e le societa' o le associazioni equiparate ne' gli enti non commerciali che non esercitano nel territorio dello Stato attivita' commerciali o che, ammessi a regimi contabili semplificati, non hanno optato per il regime ordinario. 4. Le certificazioni dei sostituti d'imposta e i documenti probatori dei versamenti eseguiti con riferimento alle dichiarazioni dei redditi e degli oneri di cui agli articoli 110, 110-bis, 113 e 114 del testo unico delle imposte sui redditi, approvato con decreto del Presidente della Repubblica 22 dicembre 1986, n. 917, nonche' ogni altro documento previsto dal decreto di cui all'articolo 8 devono essere conservati per il periodo previsto dall'articolo 43. Le certificazioni e i documenti devono essere esibiti o trasmessi, su richiesta, all'ufficio competente.".

### Art. 3. - (Dichiarazione delle societa' semplici, in nome collettivo, in accomandita semplice ed equiparate)

1. L'articolo 6 del decreto del Presidente della Repubblica 29 settembre 1973, n. 600, e' sostituito dal seguente: "Art. 6 (Dichiarazione delle societa' semplici, in nome collettivo, in accomandita semplice ed equiparate) - 1. Le societa' semplici, in nome collettivo e in accomandita semplice indicate nell'articolo 5 del testo unico delle imposte sui redditi approvato con decreto del Presidente della Repubblica 22 dicembre 1986, n. 917, le societa' e le associazioni ad esse equiparate a norma dello stesso articolo devono presentare la dichiarazione agli effetti dell'imposta locale sui redditi da esse dovuta e agli effetti dell'imposta sul reddito delle persone fisiche e dell'imposta sul reddito delle persone giuridiche dovute dai soci o dagli associati. 2. La dichiarazione deve contenere le indicazioni prescritte nel secondo comma dell'articolo 1 e nel primo comma dell'articolo 4. 3. I soggetti di cui al comma 1, anche se non obbligati da altre norme devono redigere e conservare, per il periodo indicato nell'articolo 22, il bilancio, composto dallo stato patrimoniale e dal conto dei profitti e delle perdite, relativo al periodo d'imposta. I ricavi, i costi, le rimanenze e gli altri elementi necessari, secondo le disposizioni del capo VI del titolo I del testo unico delle imposte sui redditi, approvato con decreto del Presidente della Repubblica 22 dicembre 1986, n. 917, per la determinazione dell'imponibile devono essere indicati in apposito prospetto, qualora non risultanti dal bilancio. 4. Le disposizioni del comma 3 non si applicano ai soggetti che, ammessi a regimi contabili semplificati, non hanno optato per il regime di contabilita' ordinaria, nonche' alle societa' semplici e alle societa' ed associazioni ad esse equiparate. 5. I soggetti di cui al comma 1 devono conservare, per il periodo previsto dall'articolo 43, le certificazioni dei sostituti di imposta, i documenti probatori dei crediti di imposta, dei versamenti eseguiti con riferimento alla dichiarazione dei redditi e degli oneri deducibili o detraibili, nonche' ogni altro documento previsto dal decreto di cui all'articolo 8. Le certificazioni ed i documenti devono essere esibiti o trasmessi, su richiesta, all'ufficio competente.".

### Art. 4.

((ARTICOLO ABROGATO DAL D.P.R. 22 LUGLIO 1998, N. 322))

### Art. 5.

((ARTICOLO ABROGATO DAL D.P.R. 22 LUGLIO 1998, N. 322))

### Art. 6.

((ARTICOLO ABROGATO DAL D.P.R. 22 LUGLIO 1998, N. 322))

### Art. 7.

((ARTICOLO ABROGATO DAL D.P.R. 22 LUGLIO 1998, N. 322))

### Art. 7-bis. - Violazioni in materia di trasmissione telematica delle dichiarazioni).

1. In caso di tardiva od omessa trasmissione delle dichiarazioni da parte dei soggetti indicati nel comma 3 dell'articolo 3 del decreto del Presidente della Repubblica 22 luglio 1998, n. 322, a carico dei medesimi si applica la sanzione amministrativa da lire un milione a lire dieci milioni. (16)

((1-bis. La sanzione di cui al comma 1 si applica a carico dei soggetti indicati nell'articolo 15 del decreto del Ministero delle finanze 31 luglio 1998, pubblicato nella Gazzetta Ufficiale n. 187 del 12 agosto 1998, in caso di tardiva o omessa trasmissione telematica di dichiarazioni e di atti che essi hanno assunto l'impegno a trasmettere.))

--------------- AGGIORNAMENTO (16) La L. 27 dicembre 2006, n. 296 ha disposto (con l'art. 1, comma 34) che "Per le violazioni di cui all'articolo 7-bis e ai commi 1 e 3 dell'articolo 39 del decreto legislativo 9 luglio 1997, n. 241, e successive modificazioni, ferma restando l'applicazione dell' articolo 3, comma 3, del decreto legislativo 18 dicembre 1997, n. 472, nelle ipotesi in cui la violazione sia stata gia' contestata alla data di entrata in vigore della presente legge, non si da' luogo a restituzione di quanto eventualmente pagato."

### Art. 8. - (Disposizioni in materia di dichiarazioni e di determinazione del reddito in base alle scritture contabili)

1. Al decreto del Presidente della Repubblica 29 settembre 1973, n. 600, sono apportate le seguenti modificazioni;

- a) ((LETTERA ABROGATA DAL D.P.R. 22 LUGLIO 1998, N. 322)).
- b) nell'articolo 38, terzo comma, le parole: "e dai relativi allegati" sono soppresse;
- c) nell'articolo 39, secondo comma, la lettera b) e' abrogata;
- d) nell'articolo 65, terzo comma, concernente la proroga dei termini pendenti alla data della morte del contribuente, e' aggiunto, in fine, il seguente periodo: "I soggetti incaricati dagli eredi, ai sensi del comma 2 dell'articolo 12, devono trasmettere in via telematica la dichiarazione entro il mese di gennaio dell'anno successivo a quello in cui e' scaduto il termine prorogato.".

### Art. 9. - (Disposizioni relative a taluni adempimenti dei sostituti d'imposta)

(( COMMA ABROGATO DAL D. LGS. 28 DICEMBRE 1998, N. 490 ))

2. All'articolo 78 della legge 30 dicembre 1991, n. 413, il comma 15, riguardante gli adempimenti del sostituto d'imposta nei confronti dell'amministrazione finanziaria, e' sostituito dal seguente: "15. Il sostituto d'imposta, eseguite le operazioni indicate nei commi 13 e 14 del presente articolo ed adempiuti gli obblighi indicati nell'articolo 21 del decreto del Presidente della Repubblica 29 settembre 1973, n. 600, deve trasmettere all'amministrazione finanziaria, entro il mese di luglio, le apposite dichiarazioni ricevute, rispettando i termini e le modalita' stabiliti con il decreto di cui all'articolo 8 del citato decreto n. 600 del 1973. La trasmissione delle dichiarazioni deve avvenire con le modalita' previste dall'articolo 12 del citato decreto n. 600 del 1973, per la presentazione delle dichiarazioni dei sostituti d'imposta. Il sostituto d'imposta deve inoltre inviare all'amministrazione finanziaria le schede per la scelta della destinazione dell'8 per mille dell'imposta sul reddito delle persone fisiche di cui al comma 10.".

3. Restano ferme le disposizioni di cui alla legge 2 gennaio 1997, n. 2 concernente norme per la regolamentazione della contribuzione volontaria ai movimenti o partiti politici.

### Art. 10. - (Determinazione dei contributi dovuti agli enti previdenziali)

1. I soggetti iscritti all'INPS per i propri contributi previdenziali, ad eccezione dei coltivatori diretti, e quelli iscritti agli enti e alle casse previdenziali individuati con decreto del Ministro delle finanze, di concerto con i Ministri del tesoro e del lavoro e della previdenza sociale, e all'INAIL devono determinare l'ammontare dei contributi e dei premi dovuti nella dichiarazione dei redditi. La determinazione del contributo dovuto deve essere effettuata sulla base degli imponibili stabiliti con riferimento ai redditi e ai volumi di affari dichiarati per l'anno al quale il contributo si riferisce. Con lo stesso decreto sono stabilite le modalita' di attuazione del presente articolo, considerando corrisposte a titolo di acconto le somme versate in base alle vigenti disposizioni.

2. Nel decreto del Presidente della Repubblica 29 settembre 1973, n. 605, all'articolo 20, terzo comma, riguardante il contenuto della comunicazione all'anagrafe tributaria cui le amministrazioni dello Stato sono tenute quali sostituti d'imposta, dopo il secondo periodo e' inserito il seguente: "Nel medesimo decreto puo' essere previsto anche l'obbligo di indicare i dati relativi ai contributi dovuti agli enti e casse previdenziali.".

### Art. 11. - (Dichiarazione dell'imposta sul valore aggiunto)

1. Al decreto del Presidente della Repubblica 26 ottobre 1972, n. 633, riguardante la disciplina dell'imposta sul valore aggiunto sono apportate le seguenti modificazioni:

- a) l'articolo 28 e' sostituito dal seguente: "Art. 28 (Dichiarazione annuale) - 1. Tra il 1 febbraio ed il 15 marzo di ciascun anno il contribuente deve presentare la dichiarazione relativa all'imposta dovuta per l'anno solare precedente, redatta in conformita' al modello approvato con decreto del Ministro delle finanze, da pubblicare nella Gazzetta Ufficiale entro il 20 dicembre dell'anno precedente a quello in cui deve essere utilizzato. Sono esonerati dalla presentazione della dichiarazione i contribuenti che nell'anno solare precedente hanno registrato esclusivamente operazioni esenti dall'imposta di cui all'articolo 10, salvo quelli tenuti alla effettuazione della rettifica della detrazione di cui all'articolo 19-bis. I contribuenti con periodo d'imposta coincidente, agli effetti delle imposte sui redditi, con l'anno solare obbligati alla presentazione anche della dichiarazione dei redditi e di quella del sostituto d'imposta, qualora abbiano effettuato ritenute alla fonte nei riguardi di non piu' di dieci soggetti, devono presentare, entro il termine di cui all'articolo 9 del decreto del Presidente della Repubblica 29 settembre 1973, n. 600, la dichiarazione unificata annuale, redatta in conformita' all'articolo 8 dello stesso decreto. 2. La dichiarazione deve indicare i dati e gli elementi necessari per l'individuazione del contribuente, per la determinazione dell'ammontare delle operazioni e dell'imposta nonche' per l'effettuazione dei controlli e gli altri elementi richiesti nel modello di dichiarazione, esclusi quelli che l'Amministrazione finanziaria e' in grado di acquisire direttamente. 3. Il contribuente perde il diritto alle detrazioni non computate per i mesi di competenza ne' in sede di dichiarazione annuale. 4. La dichiarazione annuale deve essere presentata anche dai contribuenti che non hanno effettuato operazioni imponibili.";
- b) nell'articolo 30, primo comma, relativo al termine per il versamento della differenza tra l'ammontare dell'imposta e l'ammontare delle somme gia' versate mensilmente, le parole: "entro il 5 marzo di ciascun anno" sono sostituite dalle seguenti: "entro il 15 marzo di ciascun anno ovvero entro il termine previsto per il pagamento delle somme dovute in base alla dichiarazione unificata annuale, maggiorando le somme da versare degli interessi nella misura dello (( 0,40 )) per cento per ogni mese o frazione di mese successivo alla predetta data";
- c) nell'articolo 33, primo comma, lettera b), riguardante il termine di versamento dell'imposta da parte dei contribuenti minori, le parole: "entro il 5 marzo di ciascun anno" sono sostituite dalle seguenti: "entro il 15 marzo di ciascun anno";
- d) nell'articolo 35-bis, concernente gli obblighi degli eredi del contribuente, il primo comma e' sostituito dal seguente: "Gli obblighi derivanti, a norma del presente decreto, dalle operazioni effettuate dal contribuente deceduto possono essere adempiuti dagli eredi, ancorche' i relativi termini siano scaduti non oltre quattro mesi prima della data della morte del contribuente, entro i sei mesi da tale data.";
- e) LETTERA ABROGATA DAL D.P.R. 22 LUGLIO 1998, N. 322.

### Art. 12. - (Decorrenza)

1. Le disposizioni del presente capo si applicano alle dichiarazioni presentate a decorrere dal 1 gennaio 1999, salvo quanto previsto nei commi seguenti.

2. La dichiarazione unificata annuale, di cui all'articolo 12 del decreto del Presidente della Repubblica 29 settembre 1973, n. 600, sostituito dall'articolo 7 del presente decreto, deve essere presentata:

- a) dalle persone fisiche, ai soli fini fiscali, a decorrere dall'anno 1998;
- b) ((LETTERA SOPPRESSA DAL D.P.R. 14 OTTOBRE 1999, N. 542 )).

3. I centri autorizzati di assistenza fiscale per le imprese e per i lavoratori dipendenti e pensionati devono trasmettere le dichiarazioni in via telematica a partire dall'anno 1998, ivi comprese le dichiarazioni previste dall'articolo 78, comma 10, della legge 30 dicembre 1991, n. 413 e le scelte effettuate in occasione della presentazione delle stesse. Per gli altri soggetti di cui all'articolo 12, comma 1, terzo periodo, del decreto del Presidente della Repubblica 29 settembre 1973, n. 600, e del comma 2 del medesimo articolo 12, come sostituito dall'articolo 7 del presente decreto, l'obbligo di trasmettere le dichiarazioni in via telematica decorre dall'anno 1999.

4. Per l'anno 1998, le dichiarazioni predisposte mediante l'utilizzo dei sistemi informatici sono consegnate o spedite per raccomandata all'amministrazione finanziaria mentre le altre sono presentate per il tramite di una banca o di un ufficio dell'Ente poste italiane, convenzionati, secondo le modalita' stabilite nel decreto di cui all'articolo 8 del decreto del Presidente della Repubblica 29 settembre 1973, n. 600. In caso di presentazione per il tramite di una banca o di un ufficio postale si applicano le disposizioni stabilite dall'articolo 12 del citato decreto n. 600 del 1973, come sostituito dall'articolo 7 del presente decreto.

5. Con decreto del Presidente del Consiglio dei Ministri, su proposta del Ministro competente, possono essere modificati, tenendo conto delle esigenze generali dei contribuenti, dei sostituti e dei responsabili d'imposta o delle esigenze organizzative dell'amministrazione, i termini riguardanti gli adempimenti degli stessi soggetti, relativi a imposte e contributi di cui al presente decreto, prevedendo l'applicazione di una maggiorazione ragguagliata allo 0,40 per cento mensile a titolo di interesse corrispettivo in caso di differimento del pagamento. Con lo stesso decreto puo' essere stabilito che non si fa luogo alla predetta maggiorazione per un periodo non superiore ai primi venti giorni; le somme dovute in base alla dichiarazione annuale relativa all'imposta sul valore aggiunto per l'anno 1998, affluiscono comunque allo Stato entro il 31 marzo 1998. A partire dal 1 gennaio 2000, la misura della maggiorazione prevista dall'articolo 11, comma 1, lettera b), e dal presente comma e' determinata con decreto del Presidente del Consiglio dei Ministri, su proposta del Ministro del tesoro, del bilancio e della programmazione economica, di concerto con il Ministro delle finanze, con riferimento all'andamento dei tassi di mercato. (10)

-------------- AGGIORNAMENTO (10) Il D.L. 17 giugno 1999, n. 179, convertito senza modificazioni dalla L. 30 luglio 1999, n. 257 ha disposto (con l'art. 1, comma 1) che "1. Per l'anno 1999 non si applica la maggiorazione dello 0,40 per cento mensile a titolo di interesse corrispettivo, prevista dall'articolo 12, comma 5, primo periodo, del decreto legislativo 9 luglio 1997, n. 241, come modificato dal decreto legislativo 24 marzo 1999, n. 81: a) ai versamenti effettuati entro il 30 giugno 1999, risultanti dalle dichiarazioni indicate all'articolo 1, commi 1 e 2, del decreto del Presidente del Consiglio dei Ministri 1 aprile 1999; b) ai versamenti effettuati entro il 20 luglio 1999 risultanti dalle suddette dichiarazioni presentate dai contribuenti che svolgono attivita' per le quali sono stati elaborati gli studi settore approvati con decreti del Ministro delle finanze 30 marzo 1999, pubblicati nei supplementi ordinari numeri 61 e 62 alla Gazzetta Ufficiale n. 75 del 31 marzo 1999, nei confronti dei quali non operano cause di esclusione o di inapplicabilita'; tale disposizione si applica anche ai titolari di redditi derivanti dalla partecipazione in societa' ed imprese familiari indicate all'articolo 5 del testo unico delle imposte sui redditi, approvato con decreto del Presidente della Repubblica 22 dicembre 1986, n. 917, ovvero in aziende coniugali non gestite in forma societaria che svolgono le medesime attivita'."

## DISPOSIZIONI IN MATERIA DI LIQUIDAZIONE E DI ACCERTAMENTO DELLE DICHIARAZIONI

### Art. 13. - (Liquidazione delle imposte sui redditi)

1. Nel decreto del Presidente della Repubblica 29 settembre 1973, n. 600, riguardante l'accertamento delle imposte sui redditi, gli articoli 36-bis e 36-ter sono sostituiti dai seguenti: "Art. 36-bis (Liquidazioni delle imposte, dei contributi, dei premi e dei rimborsi dovuti in base alle dichiarazioni) - 1. Avvalendosi di procedure automatizzate, l'amministrazione finanziaria procede, entro l'inizio del periodo di presentazione delle dichiarazioni relative all'anno successivo, alla liquidazione delle imposte, dei contributi e dei premi dovuti, nonche' dei rimborsi spettanti in base alle dichiarazioni presentate dai contribuenti e dai sostituti d'imposta. 2. Sulla base dei dati e degli elementi direttamente desumibili dalle dichiarazioni presentate e di quelli in possesso dell'anagrafe tributaria, l'Amministrazione finanziaria provvede a: a) correggere gli errori materiali e di calcolo commessi dai contribuenti nella determinazione degli imponibili, delle imposte, dei contributi e dei premi; b) correggere gli errori materiali commessi dai contribuenti nel riporto delle eccedenze delle imposte, dei contributi e dei premi risultanti dalle precedenti dichiarazioni; c) ridurre le detrazioni d'imposta indicate in misura superiore a quella prevista dalla legge ovvero non spettanti sulla base dei dati risultanti dalle dichiarazioni; d) ridurre le deduzioni dal reddito esposte in misura superiore a quella prevista dalla legge; e) ridurre i crediti d'imposta esposti in misura superiore a quella prevista dalla legge ovvero non spettanti sulla base dei dati risultanti dalle dichiarazione; f) controllare la rispondenza con la dichiarazione e la tempestivita' dei versamenti delle imposte, dei contributi e dei premi dovuti a titolo di acconto e di saldo e delle ritenute alla fonte operate in qualita' di sostituto d'imposta. 3. Quando dai controlli automatici eseguiti emerge un risultato diverso rispetto a quello indicato nella dichiarazione, l'esito della liquidazione e' comunicato al contribuente o al sostituto d'imposta per evitare la reiterazione di errori e per consentire la regolarizzazione degli aspetti formali e la comunicazione all'Amministrazione finanziaria di eventuali dati ed elementi non considerati nella liquidazione. 4. I dati contabili risultanti dalla liquidazione prevista nel presente articolo si considerano, a tutti gli effetti, come dichiarati dal contribuente e dal sostituto d'imposta. Art. 36-ter (Controllo formale delle dichiarazioni) 1. Gli uffici periferici dell'amministrazione finanziaria, procedono, entro il 31 dicembre del secondo anno successivo a quello di presentazione, al controllo formale delle dichiarazioni presentate dai contribuenti e dai sostituti d'imposta' sulla base dei criteri selettivi fissati dal Ministro delle finanze, tenendo anche conto delle capacita' operative dei medesimi uffici. 2. Senza pregiudizio dell'azione accertatrice a norma degli articoli 37 e seguenti, gli uffici possono: a) escludere in tutto o in parte lo scomputo delle ritenute d'acconto non risultanti dalle dichiarazioni dei sostituti d'imposta, dalle comunicazioni di cui all'articolo. 20, terzo comma, del decreto del Presidente della Repubblica 29 settembre 1973, n. 605, o dalle certificazioni richieste ai contribuenti ovvero delle ritenute risultanti in misura inferiore a quella indicata nelle dichiarazioni dei contribuenti stessi; b) escludere in tutto o in parte le detrazioni d'imposta non spettanti in base ai documenti richiesti ai contribuenti o agli elenchi di cui all'articolo 78, comma 25, della legge 30 dicembre 1991, n. 413; c) escludere in tutto o in parte le deduzioni dal reddito non spettanti in base ai documenti richiesti ai contribuenti o agli elenchi menzionati nella lettera b); d) determinare i crediti d'imposta spettanti in base ai dati risultanti dalle dichiarazioni e ai documenti richiesti ai contribuenti; e) liquidare la maggiore imposta sul reddito delle persone fisiche e i maggiori contributi dovuti sull'ammontare complessivo dei redditi risultanti da piu' dichiarazioni o certificati di cui all'articolo 1, comma 4, lettera d), presentati per lo stesso anno dal medesimo contribuente; f) correggere gli errori materiali e di calcolo commessi nelle dichiarazioni dei sostituti d'imposta. 3. Ai fini dei commi 1 e 2, il contribuente o il sostituto d'imposta e' invitato, anche telefonicamente o in forma scritta o telematica, a fornire chiarimenti in ordine ai dati contenuti nella dichiarazione e ad eseguire o trasmettere ricevute di versamento e altri documenti non allegati alla dichiarazione o difformi dai dati forniti da terzi. 4. L'esito del controllo formale e' comunicato al contribuente o al sostituto d'imposta con l'indicazione dei motivi che hanno dato luogo alla rettifica degli imponibili, delle imposte, delle ritenute alla fonte, dei contributi e dei premi dichiarate, per consentire anche la segnalazione di eventuali dati ed elementi non considerati o valutati erroneamente in sede di controllo formale.".

### Art. 14. - (Liquidazione dell'imposta sul valore aggiunto)

1. Al decreto del Presidente della Repubblica 26 ottobre 1972, n. 633, riguardante la disciplina dell'imposta sul valore aggiunto sono apportate le seguenti modificazioni:

- a) dopo l'articolo 54 e' inserito il seguente: "Art. 54-bis (Liquidazione dell'imposta dovuta in base alle dichiarazioni) - 1. Avvalendosi di procedure automatizzate l'amministrazione finanziaria procede, entro l'inizio del periodo di presentazione delle dichiarazioni relative all'anno successivo, alla liquidazione dell'imposta dovuta in base alle dichiarazioni presentate dai contribuenti. 2. Sulla base dei dati e degli elementi direttamente desumibili dalle dichiarazioni presentate e di quelli in possesso dell'anagrafe tributaria, l'amministrazione finanziaria provvede a: a) correggere gli errori materiali e di calcolo commessi dai contribuenti nella determinazione del volume d'affari e delle imposte; b) correggere gli errori materiali commessi dai contribuenti nel riporto delle eccedenze di imposta risultanti dalle precedenti dichiarazioni; c) controllare la rispondenza con la dichiarazione e la tempestivita' dei versamenti dell'imposta risultante dalla dichiarazione annuale a titolo di acconto e di conguaglio nonche' dalle liquidazioni periodiche di cui agli articoli 27, 33, comma 1, lettera a), e 74, quarto comma. 3. Quando dai controlli automatici eseguiti emerge un risultato diverso rispetto a quello indicato nella dichiarazione, l'esito della liquidazione e' comunicato ai sensi e per gli effetti di cui al comma 6 dell'articolo 60 al contribuente, nonche' per evitare la reiterazione di errori e per consentire la regolarizzazione degli aspetti formali e la segnalazione all'amministrazione di eventuali dati ed elementi non considerati nella liquidazione. 4. I dati contabili risultanti dalla liquidazione prevista dal presente articolo si considerano, a tutti gli effetti, come dichiarati dal contribuente.";
- b) nell'articolo 55, secondo comma, riguardante il potere di procedere ad accertamento induttivo in talune ipotesi, sono soppresse le parole: "presentata e' priva di sottoscrizione e il contribuente non ha provveduto, entro trenta giorni dal ricevimento dell'invito da parte dell'ufficio dell'imposta sul valore aggiunto, alla sottoscrizione o".

### Art. 15. - (Modifica dei termini per l'accertamento delle imposte sui redditi)

1. All'articolo 43 del decreto del Presidente della Repubblica 29 settembre 1973, n. 600, sono apportate le seguenti modificazioni:

- a) al primo comma, riguardante il termine per l'accertamento delle dichiarazioni, le parole: "entro il 31 dicembre del quinto anno successivo" sono sostituite dalle seguenti: "entro il 31 dicembre del quarto anno successivo";
- b) al secondo comma, riguardante il termine per l'accertamento in caso di omessa presentazione della dichiarazione, le parole " fino al 31 dicembre del sesto anno successivo" sono sostituite dalle seguenti: "fino al 31 dicembre del quinto anno successivo".

### Art. 16. - (Decorrenza)

1. Le disposizioni del presente capo si applicano alle dichiarazioni presentate a decorrere dal 1 gennaio 1999.

### DISPOSIZIONI IN MATERIA DI RISCOSSIONE SEZIONE I VERSAMENTO UNITARIO E COMPENSAZIONE

#### Art. 17. - (Oggetto)

1. I contribuenti eseguono versamenti unitari delle imposte, dei contributi dovuti all'INPS e delle altre somme a favore dello Stato, delle regioni e degli enti previdenziali, con eventuale compensazione dei crediti, dello stesso periodo, nei confronti dei medesimi soggetti, risultanti dalle dichiarazioni e dalle denunce periodiche presentate successivamente alla data di entrata in vigore del presente decreto. Tale compensazione deve essere effettuata entro la data di presentazione della dichiarazione successiva. La compensazione del credito annuale o relativo a periodi inferiori all'anno dell'imposta sul valore aggiunto, dei crediti relativi alle imposte sui redditi e alle relative addizionali, alle imposte sostitutive delle imposte sui redditi e all'imposta regionale sulle attivita' produttive, per importi superiori a 5.000 euro annui, puo' essere effettuata a partire dal decimo giorno successivo a quello di presentazione della dichiarazione o dell'istanza da cui il credito emerge. (6) (6A) (22) (27) (46)(53)

((

1-bis. La compensazione dei crediti di qualsiasi importo maturati a titolo di contributi nei confronti dell'INPS puo' essere effettuata:

- a) dai datori di lavoro non agricoli a partire dal quindicesimo giorno successivo a quello di scadenza del termine mensile per la trasmissione in via telematica dei dati retributivi e delle informazioni necessarie per il calcolo dei contributi da cui il credito emerge o dal quindicesimo giorno successivo alla sua presentazione, se tardiva, ovvero dalla data di notifica delle note di rettifica passive;
- b) dai datori di lavoro che versano la contribuzione agricola unificata per la manodopera agricola a decorrere dalla data di scadenza del versamento relativo alla dichiarazione di manodopera agricola da cui il credito emerge;
- c) dai lavoratori autonomi iscritti alle gestioni speciali degli artigiani ed esercenti attivita' commerciali e dai liberi professionisti iscritti alla Gestione separata presso l'INPS di cui all'articolo 2, comma 26, della legge 8 agosto 1995, n. 335, a decorrere dal decimo giorno successivo a quello di presentazione della dichiarazione dei redditi da cui il credito emerge. Resta impregiudicata la verifica sulla correttezza sostanziale del credito compensato. Sono escluse dalle compensazioni le aziende committenti per i compensi assoggettati a contribuzione alla suddetta Gestione separata presso l'INPS.

1-ter. La compensazione dei crediti di qualsiasi importo per premi e accessori maturati nei confronti dell'INAIL puo' essere effettuata a condizione che il credito certo, liquido ed esigibile sia registrato negli archivi del predetto Istituto))

2. Il versamento unitario e la compensazione riguardano i crediti e i debiti relativi:

- a) alle imposte sui redditi, alle relative adizionali e alle ritenute alla fonte riscosse mediante versamento diretto ai sensi dell'articolo 3 del decreto del Presidente della Repubblica 29 settembre 1973, n. 602; per le ritenute di cui al secondo comma del citato articolo 3 resta ferma la facolta' di eseguire il versamento presso la competente sezione di tesoreria provinciale dello Stato; in tal caso non e' ammessa la compensazione;
- b) all'imposta sul valore aggiunto dovuta ai sensi degli articoli 27 e 33 del decreto del Presidente della Repubblica 26 ottobre 1972, n. 633, e quella dovuta dai soggetti di cui all'articolo 74;
- c) alle imposte sostitutive delle imposte sui redditi e dell'imposta sul valore aggiunto;
- d) all'imposta prevista dall'articolo 3, comma 143, lettera a), della legge 23 dicembre 1996, n. 662;
- d-bis) all'imposta prevista dall'articolo 1, commi da 491 a 500, della legge 24 dicembre 2012, n. 228;
- e) ai contributi previdenziali dovuti da titolari di posizione assicurativa in una delle gestioni amministrate da enti previdenziali, comprese le quote associative;
- f) ai contributi previdenziali ed assistenziali dovuti dai datori di lavoro e dai committenti di prestazioni di collaborazione coordinata e continuativa di cui all'articolo 49, comma 2, lettera a), del testo unico delle imposte sui redditi, approvato con decreto del Presidente della Repubblica 22 dicembre 1986, n. 917;
- g) ai premi per l'assicurazione contro gli infortuni sul lavoro e le malattie professionali dovuti ai sensi del testo unico approvato con decreto del Presidente della Repubblica 30 giugno 1965, n. 1124;
- h) agli interessi previsti in caso di pagamento rateale ai sensi dell'articolo 20;
- h-bis) al saldo per il 1997 dell'imposta sul patrimonio netto delle imprese, istituita con decreto-legge 30 settembre 1992, n. 394, convertito, con modificazioni, dalla legge 26 novembre 1992, n. 461, e del contributo al Servizio sanitario nazionale di cui all'articolo 31 della legge 28 febbraio 1986, n. 41, come da ultimo modificato dall'articolo 4 del decreto-legge 23 febbraio 1995, n. 41, convertito, con modificazioni, dalla legge 22 marzo 1995, n. 85;(2)
- h-ter) alle altre entrate individuate con decreto del Ministro delle finanze, di concerto con il Ministro del tesoro, del bilancio e della programmazione economica, e con i Ministri competenti per settore;
- h-quater) al credito d'imposta spettante agli esercenti sale cinematografiche.
- h-quinquies) alle somme che i soggetti tenuti alla riscossione dell'incremento all'addizionale comunale debbono riversare all'INPS, ai sensi dell'articolo 6-quater del decreto-legge 31 gennaio 2005, n. 7, convertito, con modificazioni, dalla legge 31 marzo 2005, n. 43, e successive modificazioni.
- h-sexies) alle tasse sulle concessioni governative; (44)
- h-septies) alle tasse scolastiche. (44)

2-bis. COMMA SOPPRESSO DAL D.P.R. 14 OTTOBRE 1999, N.542.

2-ter. Qualora il credito di imposta utilizzato in compensazione risulti superiore all'importo previsto dalle disposizioni che fissano il limite massimo dei crediti compensabili ai sensi del presente articolo, il modello F24 e' scartato. La progressiva attuazione della disposizione di cui al periodo precedente e' fissata con provvedimenti del direttore dell'Agenzia delle entrate. Con provvedimento del direttore dell'Agenzia delle entrate sono altresi' indicate le modalita' con le quali lo scarto e' comunicato al soggetto interessato.

2-quater. In deroga alle previsioni di cui all'articolo 8, comma 1, della legge 27 luglio 2000, n. 212, per i contribuenti a cui sia stato notificato il provvedimento di cessazione della partita IVA, ai sensi dell'articolo 35, ((commi 15-bis e 15-bis.1)), del decreto del Presidente della Repubblica 26 ottobre 1972, n. 633, e' esclusa la facolta' di avvalersi, a partire dalla data di notifica del provvedimento, della compensazione dei crediti, ai sensi del comma 1 del presente articolo; detta esclusione opera a prescindere dalla tipologia e dall'importo dei crediti, anche qualora questi ultimi non siano maturati con riferimento all'attivita' esercitata con la partita IVA oggetto del provvedimento, e rimane in vigore fino a quando la partita IVA risulti cessata.

2-quinquies. In deroga alle previsioni di cui all'articolo 8, comma 1, della legge 27 luglio 2000, n. 212, per i contribuenti a cui sia stato notificato il provvedimento di esclusione della partita IVA dalla banca dati dei soggetti passivi che effettuano operazioni intracomunitarie, ai sensi dell'articolo 35, comma 15-bis, del decreto del Presidente della Repubblica 26 ottobre 1972, n. 633, e' esclusa la facolta' di avvalersi, a partire dalla data di notifica del provvedimento, della compensazione dei crediti IVA, ai sensi del comma 1 del presente articolo; detta esclusione rimane in vigore fino a quando non siano rimosse le irregolarita' che hanno generato l'emissione del provvedimento di esclusione.

2-sexies. Nel caso di utilizzo in compensazione di crediti in violazione di quanto previsto dai commi 2-quater e 2-quinquies, il modello F24 e' scartato. Lo scarto e' comunicato tramite i servizi telematici dell'Agenzia delle entrate al soggetto che ha trasmesso il modello F24, mediante apposita ricevuta. (15) (20) (23) (24)

--------------- AGGIORNAMENTO (2) Il D. Lgs. 23 marzo 1998, n. 56 ha disposto (con l'art. 7, comma 1) che le modifiche al presente articolo hanno effetto a decorrere dal 1 gennaio 1998. ------------- AGGIORNAMENTO (6) Il D. Lgs. 19 novembre 1998, n. 422 ha disposto (con l'art. 2, comma 2) che le disposizioni di cui al comma 1, del presente articolo 17, si applicano a decorrere dal 1 gennaio 1999. -------------- AGGIORNAMENTO (6A) La L. 23 dicembre 2000, n. 388 ha disposto (con l'art. 2, comma 10) che "In deroga all'articolo 17, comma 1, del decreto legislativo 9 luglio 1997, n. 241, e successive modificazioni, sono legittimi gli atti compiuti dai sostituti di imposta che, nell'ipotesi in cui abbiano impiegato somme proprie per corrispondere l'acconto di cui all'articolo 1 del decreto-legge 30 settembre 2000, n. 268, convertito, con modificazioni, dalla legge 23 novembre 2000, n. 354, abbiano utilizzato il relativo credito in compensazione con i versamenti da effettuare nel mese di dicembre 2000." ------------- AGGIORNAMENTO (15) Il D.L. 3 ottobre 2006, n. 262, convertito con modificazioni dalla L. 24 novembre 2006, n. 286 ha disposto (con l'art. 2, comma 16) che "L'articolo 17 del decreto legislativo 9 luglio 1997, n. 241, si interpreta nel senso che le disposizioni nello stesso previste si applicano anche ai contributi stabiliti nella legge 4 giugno 1973, n. 311." -------------- AGGIORNAMENTO (20) Il D.P.C.M. 29 luglio 2008, (in G.U. 7/8/2008, n. 184), ha disposto (con l'art. 1, comma 1) che "Gli adempimenti fiscali e il versamento delle somme di cui agli articoli 17 e 20, comma 4, del decreto legislativo 9 luglio 1997, n. 241, che hanno scadenza nel periodo compreso tra il giorno 1 ed il giorno 20 del mese di agosto 2008, possono essere effettuati entro il medesimo giorno 20, senza alcuna maggiorazione". ------------- AGGIORNAMENTO (22) Il D.L. 31 maggio 2010, n. 78, convertito con modificazioni dalla L. 30 luglio 2010, n. 122, ha disposto (con l'art. 31, comma 1) che "A decorrere dal l° gennaio 2011, la compensazione dei crediti di cui all'articolo 17, comma 1, del decreto legislativo 9 luglio 1997, n. 241, relativi alle imposte erariali, e' vietata fino a concorrenza dell'importo dei debiti, di ammontare superiore a millecinquecento euro, iscritti a ruolo per imposte erariali e relativi accessori, e per i quali e' scaduto il termine di pagamento". --------------- AGGIORNAMENTO (23) Il D.P.C.M. 27 luglio 2010 (in G.U. 03/08/2010, n. 179) ha disposto (con l'art.1, comma 1) che "Gli adempimenti fiscali e il versamento delle somme di cui agli articoli 17 e 20, comma 4, del decreto legislativo 9 luglio 1997, n. 241, che hanno scadenza nel periodo compreso tra il giorno 1 ed il giorno 20 del mese di agosto 2010, possono essere effettuati entro il medesimo giorno 20, senza alcuna maggiorazione". Ha inoltre disposto (con l'art. 1, comma 2) che "Resta ferma la scadenza del versamento, maggiorato dell'importo nella misura dello 0,40 per cento a titolo di interesse corrispettivo, dovuto ai sensi dell'articolo 1, comma 1, lett. b), del decreto del Presidente del Consiglio dei Ministri 10 giugno 2010, concernente il differimento, per l'anno 2010, dei termini di effettuazione dei versamenti dovuti dai soggetti che esercitano attivita' economiche per le quali sono state elaborati gli studi di settore, nonche' il differimento del termine per la trasmissione in via telematica delle dichiarazioni modello 730/2010". --------------- AGGIORNAMENTO (24) IL D.Lgs. 9 luglio 1997, n. 241, come modificato dal D.L. 2 marzo 2012, n. 16, convertito con modificazioni dalla L. 26 aprile 2012, n. 44, ha disposto (con l'art. 37, comma 11-bis) che "Gli adempimenti fiscali e il versamento delle somme di cui agli articoli 17 e 20, comma 4, del decreto legislativo 9 luglio 1997, n. 241, che hanno scadenza dal 1º al 20 agosto di ogni anno, possono essere effettuati entro il giorno 20 dello stesso mese, senza alcuna maggiorazione". --------------- AGGIORNAMENTO (27) Il D.Lgs. 21 novembre 2014, n. 175 ha disposto (con l'art. 15, comma 1, lettera b)) che, al fine di favorire la trasparenza e semplificare le operazioni poste in essere dai sostituti d'imposta, a decorrere dal 1° gennaio 2015 "in deroga a quanto previsto dall'articolo 17, comma 1, del decreto legislativo n. 241 del 1997 le eccedenze di versamento di ritenute e di imposte sostitutive sono scomputate dai successivi versamenti esclusivamente con le modalita' di cui all'articolo 17 del citato decreto legislativo n. 241 del 1997. Dette somme non concorrono alla determinazione del limite di cui all'articolo 34, comma 1, della legge n. 388 del 2000 fermo restando quanto previsto dall'articolo 1, commi da 2 a 6, del decreto del Presidente della Repubblica 10 novembre 1997, n. 445". --------------- AGGIORNAMENTO (44) Il D.L. 30 aprile 2019, n. 34, convertito con modificazioni dalla L. 28 giugno 2019, n. 58, ha disposto (con l'art. 4-quater, comma 2) che "Le disposizioni di cui alle lettere h-sexies) e h-septies) del comma 2 dell'articolo 17 del decreto legislativo 9 luglio 1997, n. 241, introdotte dal comma 1 del presente articolo, acquistano efficacia a decorrere dal primo giorno del sesto mese successivo a quello in corso alla data di entrata in vigore della legge di conversione del presente decreto e, in ogni caso, non prima del 1° gennaio 2020". --------------- AGGIORNAMENTO (46) Il D.L. 26 ottobre 2019, n. 124 ha disposto (con l'art. 3, comma 3) che "Le disposizioni dei commi 1 e 2 si applicano con riferimento ai crediti maturati a decorrere dal periodo d'imposta in corso al 31 dicembre 2019". --------------- AGGIORNAMENTO (53) Il D.L. 16 febbraio 2023, n. 11, convertito con modificazioni dalla L. 11 aprile 2023, n. 38, ha disposto (con l'art. 2-quater, comma 1) che "L'articolo 17, comma 1, primo periodo, del decreto legislativo 9 luglio 1997, n. 241, si interpreta nel senso che la compensazione ivi prevista puo' avvenire, nel rispetto delle disposizioni vigenti, anche tra debiti e crediti, compresi quelli di cui all'articolo 121 del decreto-legge 19 maggio 2020, n. 34, convertito, con modificazioni, dalla legge 17 luglio 2020, n. 77, nei confronti di enti impositori diversi".

#### Art. 17-bis. - (( (Ritenute e compensazioni in appalti e subappalti ed estensione del regime del reverse charge per il contrasto dell'illecita somministrazione di manodopera). ))

((

1. In deroga alla disposizione di cui all'articolo 17, comma 1, i soggetti di cui all'articolo 23, comma 1, del decreto del Presidente della Repubblica 29 settembre 1973, n. 600, residenti ai fini delle imposte dirette nello Stato, ai sensi degli articoli 2, comma 2, 5, comma 3, lettera d), e 73, comma 3, del testo unico delle imposte sui redditi, di cui al decreto del Presidente della Repubblica 22 dicembre 1986, n. 917, che affidano il compimento di una o piu' opere o di uno o piu' servizi di importo complessivo annuo superiore a euro 200.000 a un'impresa, tramite contratti di appalto, subappalto, affidamento a soggetti consorziati o rapporti negoziali comunque denominati caratterizzati da prevalente utilizzo di manodopera presso le sedi di attivita' del committente con l'utilizzo di beni strumentali di proprieta' di quest'ultimo o ad esso riconducibili in qualunque forma, sono tenuti a richiedere all'impresa appaltatrice o affidataria e alle imprese subappaltatrici, obbligate a rilasciarle, copia delle deleghe di pagamento relative al versamento delle ritenute di cui agli articoli 23 e 24 del citato decreto del Presidente della Repubblica n. 600 del 1973, 50, comma 4, del decreto legislativo 15 dicembre 1997, n. 446, e 1, comma 5, del decreto legislativo 28 settembre 1998, n. 360, trattenute dall'impresa appaltatrice o affidataria e dalle imprese subappaltatrici ai lavoratori direttamente impiegati nell'esecuzione dell'opera o del servizio. Il versamento delle ritenute di cui al periodo precedente e' effettuato dall'impresa appaltatrice o affidataria e dall'impresa subappaltatrice, con distinte deleghe per ciascun committente, senza possibilita' di compensazione.

2. Al fine di consentire al committente il riscontro dell'ammontare complessivo degli importi versati dalle imprese, entro i cinque giorni lavorativi successivi alla scadenza del versamento di cui all'articolo 18, comma 1, l'impresa appaltatrice o affidataria e le imprese subappaltatrici trasmettono al committente e, per le imprese subappaltatrici, anche all'impresa appaltatrice le deleghe di cui al comma 1 del presente articolo e un elenco nominativo di tutti i lavoratori, identificati mediante codice fiscale, impiegati nel mese precedente direttamente nell'esecuzione di opere o servizi affidati dal committente, con il dettaglio delle ore di lavoro prestate da ciascun percipiente in esecuzione dell'opera o del servizio affidato, l'ammontare della retribuzione corrisposta al dipendente collegata a tale prestazione e il dettaglio delle ritenute fiscali eseguite nel mese precedente nei confronti di tale lavoratore, con separata indicazione di quelle relative alla prestazione affidata dal committente.

3. Nel caso in cui alla data di cui al comma 2 sia maturato il diritto a ricevere corrispettivi dall'impresa appaltatrice o affidataria e questa o le imprese subappaltatrici non abbiano ottemperato all'obbligo di trasmettere al committente le deleghe di pagamento e le informazioni relative ai lavoratori impiegati di cui al medesimo comma 2 ovvero risulti l'omesso o insufficiente versamento delle ritenute fiscali rispetto ai dati risultanti dalla documentazione trasmessa, il committente deve sospendere, finche' perdura l'inadempimento, il pagamento dei corrispettivi maturati dall'impresa appaltatrice o affidataria sino a concorrenza del 20 per cento del valore complessivo dell'opera o del servizio ovvero per un importo pari all'ammontare delle ritenute non versate rispetto ai dati risultanti dalla documentazione trasmessa, dandone comunicazione entro novanta giorni all'ufficio dell'Agenzia delle entrate territorialmente competente nei suoi confronti. In tali casi, e' preclusa all'impresa appaltatrice o affidataria ogni azione esecutiva finalizzata al soddisfacimento del credito il cui pagamento e' stato sospeso, fino a quando non sia stato eseguito il versamento delle ritenute.

4. In caso di inottemperanza agli obblighi previsti dai commi 1 e 3, il committente e' obbligato al pagamento di una somma pari alla sanzione irrogata all'impresa appaltatrice o affidataria o subappaltatrice per la violazione degli obblighi di corretta determinazione delle ritenute e di corretta esecuzione delle stesse, nonche' di tempestivo versamento, senza possibilita' di compensazione.

5. Gli obblighi previsti dal presente articolo non trovano applicazione qualora le imprese appaltatrici o affidatarie o subappaltatrici di cui al comma 1 comunichino al committente, allegando la relativa certificazione, la sussistenza, nell'ultimo giorno del mese precedente a quello della scadenza prevista dal comma 2, dei seguenti requisiti:

- a) risultino in attivita' da almeno tre anni, siano in regola con gli obblighi dichiarativi e abbiano eseguito nel corso dei periodi d'imposta cui si riferiscono le dichiarazioni dei redditi presentate nell'ultimo triennio complessivi versamenti registrati nel conto fiscale per un importo non inferiore al 10 per cento dell'ammontare dei ricavi o compensi risultanti dalle dichiarazioni medesime;
- b) non abbiano iscrizioni a ruolo o accertamenti esecutivi o avvisi di addebito affidati agli agenti della riscossione relativi alle imposte sui redditi, all'imposta regionale sulle attivita' produttive, alle ritenute e ai contributi previdenziali per importi superiori ad euro 50.000, per i quali i termini di pagamento siano scaduti e siano ancora dovuti pagamenti o non siano in essere provvedimenti di sospensione. Le disposizioni di cui al periodo precedente non si applicano per le somme oggetto di piani di rateazione per i quali non sia intervenuta decadenza.

6. A decorrere dalla data di applicazione della presente disposizione, la certificazione di cui al comma 5 e' messa a disposizione delle singole imprese dall'Agenzia delle entrate e ha validita' di quattro mesi dalla data del rilascio.

7. Con provvedimento del direttore dell'Agenzia delle entrate possono essere disciplinate ulteriori modalita' di trasmissione telematica delle informazioni previste dal comma 2 che consentano modalita' semplificate di riscontro dei dati di cui allo stesso comma.

8. In deroga alla disposizione di cui all'articolo 17, comma 1, per le imprese appaltatrici o affidatarie e per le imprese subappaltatrici di cui al comma 1 del presente articolo e' esclusa la facolta' di avvalersi dell'istituto della compensazione quale modalita' di estinzione delle obbligazioni relative a contributi previdenziali e assistenziali e premi assicurativi obbligatori, maturati in relazione ai dipendenti di cui al medesimo comma 1. Detta esclusione opera con riguardo a tutti i contributi previdenziali e assistenziali e ai premi assicurativi maturati, nel corso della durata del contratto, sulle retribuzioni erogate al personale direttamente impiegato nell'esecuzione delle opere o dei servizi affidati. Le disposizioni del presente comma non si applicano ai soggetti di cui al comma 5))

((46))

-------------- AGGIORNAMENTO (46) Il D.L. 26 ottobre 2019, n. 124, convertito con modificazioni dalla L. 19 dicembre 2019, n. 157, ha disposto (con l'art. 4, comma 2) che "Le disposizioni di cui al comma 1 si applicano a decorrere dal 1° gennaio 2020".

#### Art. 18. - (Termini di versamento)

1. Le somme di cui all'articolo 17 devono essere versate entro il giorno ((sedici)) del mese di scadenza. Se il termine scade di sabato o di giorno festivo il versamento e' tempestivo se effettuato il primo giorno lavorativo successivo. (3) ((6))

2. I versamenti dovuti da soggetti titolari di posizione assicurativa in una delle gestioni amministrate dall'INPS, per le quote contributive comprese entro il minimale, sono effettuati nei mesi di febbraio, maggio, agosto e novembre

3. Rimangono invariati i termini di scadenza delle somme dovute a titolo di saldo e di acconto in base alle dichiarazioni annuali ((, nonche' il termine previsto dall'articolo 6, comma 2, della legge 29 dicembre 1990, n. 405, per il pagamento dell'imposta sul valore aggiunto dovuta a titolo di acconto del versamento relativo al mese di dicembre)).

4. I versamenti a saldo e in acconto dei contributi dovuti agli enti previdenziali da titolari di posizione assicurativa in una delle gestioni amministrate da enti previdenziali sono effettuati entro gli stessi termini previsti per il versamento delle somme dovute in base alla dichiarazione dei redditi.

----------------- AGGIORNAMENTO (3) Il D.L. 12 giugno 1998, n. 181 convertito con modificazioni dalla L. 3 agosto 1998, n. 271 ha disposto (con l'art. 1, comma 2) che " Per il mese di giugno 1998, il termine per il versamento unificato di cui all'articolo 18, comma 1, del decreto legislativo 9 luglio 1997, n. 241, e' fissato al 19 giugno." ------------------ AGGIORNAMENTO (6) Il D.Lgs. 19 novembre 1998, n. 422 ha disposto (con l'art. 2, comma 2) che le disposizioni di cui al comma 1 del presente articolo si applicano a decorrere dal 1 gennaio 1999.

#### Art. 19. - Modalita' di versamento mediante delega

1. I versamenti delle imposte, dei contributi, dei premi previdenziali ed assistenziali e delle altre somme, al netto della compensazione, sono eseguiti mediante delega irrevocabile ad una banca convenzionata ai sensi del comma 5.

2. La banca rilascia al contribuente un'attestazione conforme al modello approvato con decreto del Ministro delle finanze, recante l'indicazione dei dati identificativi del soggetto che effettua il versamento, la data, la causale e gli importi dell'ordine di pagamento, nonche' l'impegno ad effettuare il pagamento agli enti destinatari per conto del delegante. L'attestazione deve recare altresi' l'indicazione dei crediti per i quali il contribuente si e' avvalso della facolta' di compensazione.

3. La delega deve essere conferita dal contribuente anche nell'ipotesi in cui le somme dovute risultano totalmente compensate ai sensi dell'articolo 17. La parte di credito che non ha trovato capienza nella compensazione e' utilizzata in occasione del primo versamento successivo. 4.((COMMA ABROGATO DAL D.LGS. 24 SETTEMBRE 2015, N. 158, COME MODIFICATO DALLA LEGGE 28 DICEMBRE 2015, N. 208)). ((28)) 5. Con convenzione approvata con decreto del Ministro delle finanze, di concerto con i Ministri del tesoro e del lavoro e della previdenza sociale, sono stabiliti le modalita' di conferimento della delega e di svolgimento del servizio, i dati delle operazioni da trasmettere e le relative modalita' di trasmissione e di conservazione, tenendo conto dei termini di cui all'articolo 13 del regolamento concernente l'istituzione del conto fiscale, adottato con decreto del Ministro delle finanze 28 dicembre 1993, n. 567, nonche' le penalita' per l'inadempimento degli obblighi nascenti dalla convenzione stessa e la misura del compenso per il servizio svolto dalle banche. Quest'ultima e' determinata tenendo conto del costo di svolgimento del servizio, del numero dei moduli presentati dal contribuente e di quello delle operazioni in esso incluse, della tipologia degli adempimenti da svolgere e dell'ammontare complessivo dei versamenti gestito dal sistema. La convenzione ha durata triennale e puo' essere tacitamente rinnovata. (22) 6. Con decreto del Ministro delle finanze, di concerto con i Ministri del tesoro e delle poste e delle telecomunicazioni, la delega di pagamento puo' essere conferita all'ente poste italiane, secondo modalita' e termini in esso fissati. All'Ente poste italiane si applicano le disposizioni del presente decreto.

------------ AGGIORNAMENTO (22) Il D.L. 6 luglio 2011, n. 98, convertito con modificazioni dalla L. 15 luglio 2011, n. 111, ha disposto (con l'art. 22, comma 2) che "le convenzioni regolanti le modalita' di svolgimento del servizio di riscossione dei versamenti unitari, ai sensi dell'articolo 19, comma 5, del decreto legislativo 9 luglio 1997, n. 241, potranno prevedere, oltre all'applicazione dell'interesse determinato nei termini di cui all'articolo 46, comma 5, della legge 31 dicembre 2009, n. 196, ulteriori penalita' in caso di mancato rispetto degli obblighi fissati dalle presenti disposizioni". ------------- AGGIORNAMENTO (28) Il D.Lgs. 24 settembre 2015, n. 158 aveva precedentemente disposto (con l'art. 32, comma 2, lettera c)) l'abrogazione del comma 4 del presente articolo a decorrere dal 1 gennaio 2017.

#### Art. 20. - (Pagamenti rateali)

1. Le somme dovute a titolo di saldo e di acconto delle imposte e dei contributi dovuti dai soggetti titolari di posizione assicurativa in una delle gestioni amministrate dall'INPS , ad eccezione di quelle dovute nel mese di dicembre a titolo di acconto del versamento dell'imposta sul valore aggiunto, possono essere versate ((...)) in rate mensili di uguale importo, con la maggiorazione degli interessi di cui al comma 2, decorrenti dal mese di scadenza, in ogni caso, il pagamento deve essere completato entro il ((16 dicembre)) dello stesso anno di presentazione della dichiarazione o della denuncia. La disposizione non si applica per le somme dovute ai sensi del titolo III del decreto del Presidente della Repubblica 29 settembre 1973, n. 600. ((59))

2. La misura dell'interesse e' pari al tasso previsto dall'articolo 9 del decreto del Presidente della Repubblica 29 settembre 1973, n. 602, maggiorato di un punto percentuale.

3. La facolta' del comma 1 puo' essere esercitata anche dai soggetti non ammessi alla compensazione di cui all'articolo 17, comma 1.

((4. I versamenti rateali sono effettuati entro il giorno 16 di ciascun mese.))

((59))

5. Le disposizioni del comma 2 si applicano per il calcolo degli interessi di cui all'articolo 3, commi 8 e 9, del decreto del Presidente della Repubblica 4 settembre 1992, n. 395, riguardante gli adempimenti del sostituto d'imposta per il controllo della dichiarazione e per la liquidazione delle imposte e del contributo al Servizio sanitario nazionale.

-------------- AGGIORNAMENTO (6) Il D. Lgs. 19 novembre 1998, n. 422 ha disposto (con lart. 2, comma 2) che le disposizioni di cui al comma 4, del presente articolo si applicano a decorrere dal 1 gennaio 1999. --------------- AGGIORNAMENTO (20) Il D.P.C.M. 29 luglio 2008, (in G.U. 7/8/2008, n. 184), ha disposto (con l'art. 1, comma 1) che "Gli adempimenti fiscali e il versamento delle somme di cui agli articoli 17 e 20, comma 4, del decreto legislativo 9 luglio 1997, n. 241, che hanno scadenza nel periodo compreso tra il giorno 1 ed il giorno 20 del mese di agosto 2008, possono essere effettuati entro il medesimo giorno 20, senza alcuna maggiorazione". --------------- AGGIORNAMENTO (23) Il D.P.C.M. 27 luglio 2010 (in G.U. 03/08/2010, n. 179) ha disposto (con l'art.1, comma 1) che "Gli adempimenti fiscali e il versamento delle somme di cui agli articoli 17 e 20, comma 4, del decreto legislativo 9 luglio 1997, n. 241, che hanno scadenza nel periodo compreso tra il giorno 1 ed il giorno 20 del mese di agosto 2010, possono essere effettuati entro il medesimo giorno 20, senza alcuna maggiorazione". Ha inoltre disposto (con l'art. 1, comma 2) che "Resta ferma la scadenza del versamento, maggiorato dell'importo nella misura dello 0,40 per cento a titolo di interesse corrispettivo, dovuto ai sensi dell'articolo 1, comma 1, lett. b), del decreto del Presidente del Consiglio dei Ministri 10 giugno 2010, concernente il differimento, per l'anno 2010, dei termini di effettuazione dei versamenti dovuti dai soggetti che esercitano attivita' economiche per le quali sono state elaborati gli studi di settore, nonche' il differimento del termine per la trasmissione in via telematica delle dichiarazioni modello 730/2010". -------------- AGGIORNAMENTO (24) IL D.Lgs. 9 luglio 1997, n. 241, come modificato dal D.L. 2 marzo 2012, n. 16, convertito con modificazioni dalla L. 26 aprile 2012, n. 44, ha disposto (con l'art. 37, comma 11-bis) che "Gli adempimenti fiscali e il versamento delle somme di cui agli articoli 17 e 20, comma 4, del decreto legislativo 9 luglio 1997, n. 241, che hanno scadenza dal 1º al 20 agosto di ogni anno, possono essere effettuati entro il giorno 20 dello stesso mese, senza alcuna maggiorazione". -------------- AGGIORNAMENTO (59) Il D.Lgs. 8 gennaio 2024, n. 1 ha disposto (con l'art. 8, comma 2) che le presenti modifiche si applicano a decorrere dal versamento delle somme dovute a titolo di saldo delle imposte relative al periodo d'imposta in corso al 31 dicembre 2023.

#### Art. 21. - Adempimenti delle banche

1. Entro il quinto giorno lavorativo successivo a quello di ricevimento della delega, la banca versa le somme riscosse alla tesoreria dello Stato o alla Cassa regionale siciliana di Palermo, al netto del compenso ad essa spettante. Si considerano non lavorativi i giorni di sabato e quelli festivi. (6)

2. Entro il termine di cui al comma 1 la banca predispone ed invia telematicamente alla struttura di gestione di cui all'articolo 22 i dati riepilogativi delle somme a debito e a credito complessivamente evidenziate nelle deleghe di pagamento, distinte per ciascun ente destinatario.

((

2-bis. Con convenzione, fermi restando i termini fissati dai commi 1 e 2, puo' essere stabilito che:

- a) entro il secondo giorno lavorativo successivo a quello di ricevimento della delega, la banca comunica alla struttura di gestione l'importo presuntivo delle somme che versera' ai sensi del comma 1;
- b) entro il terzo giorno lavorativo successivo a quello di ricevimento della delega, la banca versa almeno l'80 per cento delle predette somme.

))

3. Con decreto del Ministro delle finanze, di concerto con i Ministri del tesoro e del lavoro e della previdenza sociale, sono stabilite le modalita' applicative nonche' i criteri per i controlli relativi all'esecuzione del servizio da parte delle banche e le modalita' di scambio dei dati fra gli interessati. ----------------- AGGIORNAMENTO (6) Il D. Lgs. 19 novembre 1998, n. 422 ha disposto (con l'art. 2, comma 2) che le disposizioni di cui al comma 1, del presente articolo si applicano a decorrere dal 1 gennaio 1999.

#### Art. 22. - (Suddivisione delle somme tra gli enti destinatari)

1. Entro il primo giorno lavorativo successivo a quello di versamento delle somme da parte delle banche e di ricevimento dei relativi dati riepilogativi, un'apposita struttura di gestione attribuisce agli enti destinatari le somme a ciascuno di essi spettanti, tenendo conto dell'eventuale compensazione eseguita dai contribuenti.

2. Gli enti destinatari delle somme dispongono con cadenza trimestrale le regolazioni contabili sulle contabilita' di pertinenza a copertura delle somme compensate dai contribuenti.

3. La struttura di gestione di cui al comma 1 e' individuata con decreto del Ministro delle finanze, di concerto con i Ministri del tesoro e del lavoro e della previdenza sociale. Con decreto del Ministero delle finanze, di concerto con i Ministri del tesoro e del lavoro e della previdenza sociale, sono stabilite le modalita' per l'attribuzione delle somme.

4. La compensazione di cui all'articolo 17 puo' operare soltanto dopo l'emanazione dei decreti indicati nel comma 3.

#### Art. 23. - (Pagamento con mezzi diversi dal contante)

1. I contribuenti possono mettere a disposizione delle banche convenzionate ai sensi del comma 2 le somme oggetto della delega anche mediante carte di debito, di credito e prepagate, assegni bancari e circolari ovvero mediante altri sistemi di pagamento. Se gli assegni risultano scoperti o comunque non pagabili, il conferimento della delega si considera non effettuato e il versamento omesso.

2. Le modalita' di esecuzione dei pagamenti mediante i sistemi di cui al comma 1 sono stabilite con convenzione approvata con decreto del Ministro delle finanze, di concerto con il Ministro del tesoro.

## DISPOSIZIONI RELATIVE AL PERIODO TRANSITORIO

### Art. 24. - (Modalita' di versamento)

1. Fino ((al 31 dicembre 1998)), i versamenti unitari eseguiti dai titolari di partita IVA sono effettuati ai concessionari della riscossione anche mediante delega ad una banca convenzionata.

2. Le somme relative ai contributi previdenziali sono versate dalle banche direttamente alla tesoreria dello Stato, secondo le modalita' previste dal regolamento di cui al comma 10, le somme di cui all'imposta prevista dall'articolo 3, comma 143, lettera a), della legge 23 dicembre 1996, n. 662, sono versate dalle banche direttamente alla tesoreria dello Stato.

3. I concessionari, per le somme di cui al comma 2, ricevute direttamente dai contribuenti, eseguono i medesimi versamenti sempre con le modalita' stabilite dal regolamento previsto al comma 10.

4. Le distinte di versamento con le quali sono effettuati i pagamenti di cui al comma 1 sono approvate con decreto del Ministero delle finanze da pubblicare sulla Gazzetta Ufficiale.

5. Per la riscossione dei versamenti diretti previsti dal presente articolo, riscossi direttamente o tramite delega, spetta ai concessionari la commissione prevista dall'articolo 61, comma 3, lettera a), del decreto del Presidente della Repubblica 28 gennaio 1988, n. 43, tenendo altresi' conto di ciascun modulo di versamento presentato dal contribuente, dell'ammontare complessivo dei versamenti gestiti dal sistema, della tipologia delle operazioni e del costo del servizio, sentita l'associazione di categoria interessata.

6. A decorrere dalla data di entrata in vigore del presente articolo, e' abrogato l'articolo 5 del decreto del Presidente della Repubblica 28 settembre 1973, n. 602.

7. Le disposizioni contenute nell'articolo 23 si applicano anche ai concessionari della riscossione. Con uno o piu' decreti del Ministro delle finanze sono stabilite le modalita' di esecuzione dei pagamenti mediante sistemi diversi dal contante.

8. Per le banche si applicano le disposizioni di cui all'articolo 19, comma 4. La convenzione rimane in vigore per il periodo previsto dai commi 1 e 4 del presente articolo e, in ogni caso, per non piu' di tre anni e puo' essere rinnovata tacitamente.

9. All'attivazione della riscossione mediante conferimento all'Ente poste italiane di delega di versamento al concessionario della riscossione, si provvedera' successivamente all'emanazione del decreto previsto dall'articolo 19, comma 5.

10. Con regolamento, da emanare ai sensi dell'articolo 17, comma 2, della legge 23 agosto 1988, n. 400, entro 120 giorni dalla data di entrata in vigore del presente: decreto, sono disciplinati, sulla base delle previsioni contenute nella sezione I del presente Capo e dell'articolo 11 del decreto ministeriale 28 dicembre 1993, n. 567, le modalita' di versamento in Tesoreria delle somme riscosse dai soggetti indicati nel presente articolo durante il periodo transitorio di cui al comma 1 e l'invio telematico dei relativi dati alla struttura di gestione di cui all'articolo 22.

### Art. 25. - (Decorrenza e garanzie)

1. Il regime dei versamenti unitari entra in funzione per tutti i contribuenti a partire dal mese di maggio 1998. Sono ammessi alla compensazione:

- a) dall'anno 1998 le persone fisiche titolari di partita IVA;
- b) dall'anno 1999 le societa' di persone ed equiparate ai fini fiscali ((, nonche' i soggetti non titolari di partita IVA));
- c) dall'anno 2000 i soggetti all'imposta sul reddito delle persone giuridiche.(2)

2. Il limite massimo dei crediti d'imposta e dei contributi che possono essere compensati, e', fino all'anno 2000, fissato in lire 500 milioni per ciascun periodo d'imposta.

3. Con decreto del Presidente del Consiglio dei Ministri, su proposta del Ministro delle finanze, di concerto con il Ministro del tesoro, possono essere modificati i termini di cui al comma 1, lettere a), b) e c), tenendo conto delle esigenze organizzative e di bilancio.

4. I contribuenti titolari di partita IVA non ammessi alla compensazione o, seppure ammessi, per la parte che non trova capienza nella compensazione, pur nel rispetto del limite di cui al comma 2, possono ricorrere alla procedura di rimborso prevista dal titolo II del regolamento concernente l'istituzione del conto fiscale, adottato con decreto del Ministro delle finanze 28 dicembre 1993, n. 567. La garanzia e' prestata ai sensi dell'articolo 38-bis, comma 1, del Decreto del Presidente della Repubblica 26 ottobre 1972, n. 633. ((PERIODO SOPPRESSO DAL D. LGS. 19 NOVEMBRE 1998, N. 422)). PERIODO SOPPRESSO DAL D. LGS. 23 MARZO 1998, N. 56. (2)

-------------- AGGIORNAMENTO (2) Il D. Lgs. 23 marzo 1998, n. 56 ha disposto (con l'art. 7, comma 1) che le modifiche al presente articolo hanno effetto a decorrere dal 1 gennaio 1998.

## SANZIONI

### Art. 26. - (Sanzioni al concessionario)

1. In caso di minore versamento alla tesoreria dello Stato o alla cassa regionale siciliana di Palermo delle somme riscosse dal concessionario direttamente ovvero pagate per delega alle banche si applicano le disposizioni contenute nell'articolo 104 del decreto del Presidente della Repubblica 28 gennaio 1988, n. 43.

2. In caso di ritardato invio dei dati di cui all'articolo 21, comma 2, si applica la sanzione amministrativa pecuniaria di lire 10.000.000 per ogni giorno di ritardo; la stessa sanzione si applica in caso di irregolarita' che non consentano l'attribuzione delle somme agli enti destinatari.

3. I casi di reiterate e rilevanti infrazioni all'obbligo di invio dei dati delle operazioni, eseguite nell'ambito delle attivita' di riscossione, costituiscono specifica causa di decadenza dalla concessione.

## DISPOSIZIONI VARIE

### Art. 27. - (Comitato di indirizzo)

1. Presso il Ministero delle finanze e' istituito un comitato di indirizzo, controllo e valutazione dell'attuazione di quanto previsto dall'articolo 3, comma 134, della legge 23 dicembre 1996, n. 662.

2. Il comitato e' nominato dal Ministro delle finanze di concerto con i Ministri del tesoro e del lavoro e della previdenza sociale; del comitato fa parte il Ministro delle finanze con funzioni di presidente.

3. Il comitato, sulla base delle risultanze gestionali del sistema introdotto, propone modifiche al presente decreto legislativo.

### Art. 28. - (Versamenti in favore di enti previdenziali)

1. I versamenti unitari e la compensazione previsti dal presente capo si applicano a decorrere dal 1999 anche all'INAIL, all'Ente nazionale per la previdenza e l'assistenza per i lavoratori dello spettacolo (ENPALS) e all'Istituo nazionale per la previdenza per i dirigenti di aziende industriali (INPDAI) agli enti e casse previdenziali individuati con decreto del Ministro delle finanze, di concerto con i Ministri del tesoro e del lavoro e della previdenza sociale.

2. Con decreto emanato dalle stesse autorita' ministeriali, la decorrenza di cui al comma 1 puo' essere modificata, tenendo conto di esigenze organizzative.

### Articolo 29 - (Copertura finanziaria)

1. Agli oneri derivanti dalla applicazione del presente decreto valutati in lire 300 miliardi per il 1998, il lire 630 miliardi per l'anno 1999 e in lire 1.200 miliardi a decorrere dall'anno 2000, si provvede con le maggiori entrate recate dal presente decreto.

2. Il Ministro del tesoro e' autorizzato ad apportare, con propri decreti, le occorrenti variazioni di bilancio.

## DISPOSIZIONI IN MATERIA DI RIMBORSI

### Art. 30.

((ARTICOLO ABROGATO DAL D.LGS. 24 MARZO 2025, N. 33))

### Art. 31. - (Rimborso del credito IVA)

1. All'articolo 38-bis, primo comma, del decreto del Presidente della Repubblica 26 ottobre 1972, n. 633, concernente l'esecuzione dei rimborsi, sono aggiunti, in fine, i seguenti periodi: "I rimborsi previsti nell'articolo 30 possono essere richiesti, utilizzando apposita dichiarazione redatta su modello approvato con decreto dirigenziale contenente i dati che hanno determinato l'eccedenza di credito, a decorrere dal primo febbraio dell'anno successivo a quello di riferimento; in tal caso i rimborsi sono eseguiti entro tre mesi dalla presentazione della dichiarazione, che vale come dichiarazione annuale limitatamente ai dati in essa indicati, con le modalita' stabilite dal presente articolo e, agli effetti del computo degli interessi, si tiene conto della data di presentazione della dichiarazione stessa. I rimborsi di cui al presente comma possono essere richiesti con apposita istanza, anche ai competenti concessionari della riscossione secondo le modalita' stabilite dall'articolo 78, commi 27 e seguenti, della legge 30 dicembre 1991, n. 413, e dai relativi regolamenti di attuazione.". Il presente decreto, munito del sigillo dello Stato, sara' inserito nella Raccolta ufficiale degli atti normativi della Repubblica italiana. E' fatto obbligo a chiunque spetti di osservarlo e di farlo osservare. Dato a Roma, addi' 9 luglio 1997 SCALFARO Prodi, Presidente del Consiglio dei Ministri Visco, Ministro delle finanze Ciampi, Ministro del tesoro Visto, il Guardasigilli: Flick

## DISPOSIZIONI IN MATERIA DI ASSISTENZA FISCALE))

### Art. 32. - (( (Soggetti abilitati alla costituzione dei centri di assistenza fiscale). ))

((

1. I centri di assistenza fiscale, di seguito denominati ''Centri'', possono essere costituiti dai seguenti soggetti:

- a) associazioni sindacali di categoria fra imprenditori, presenti nel Consiglio nazionale dell'economia e del lavoro, istituite da almeno dieci anni;
- b) associazioni sindacali di categoria fra imprenditori, istituite da almeno dieci anni, diverse da quelle indicate nella lettera a) se, con decreto del Ministero delle finanze, ne e' riconosciuta la rilevanza nazionale con riferimento al numero degli associati, almeno pari al 5 per cento degli appartenenti alla stessa categoria, iscritti negli appositi registri tenuti dalla camera di commercio, nonche' all'esistenza di strutture organizzate in almeno 30 province;
- c) organizzazioni aderenti alle associazioni di cui alle lettere a) e b), previa delega della propria associazione nazionale;
- d) organizzazioni sindacali dei lavoratori dipendenti e pensionati od organizzazioni territoriali da esse delegate, aventi complessivamente almeno cinquantamila aderenti;
- e) sostituti di cui all'articolo 23 del decreto del Presidente della Repubblica 29 settembre 1973, n. 600, e successive modificazioni, aventi complessivamente almeno cinquantamila dipendenti;
- f) associazioni di lavoratori promotrici di istituti di patronato riconosciuti ai sensi del decreto legislativo del Capo provvisorio dello Stato 29 luglio 1947, n. 804, aventi complessivamente almeno cinquantamila aderenti.

))

### Art. 33. - (( (Requisiti soggettivi). ))

((

1. I centri sono costituiti nella forma di societa' di capitali. L'oggetto sociale dei centri prevede lo svolgimento delle attivita' di assistenza fiscale di cui all'articolo 34.

2. I centri designano uno o piu' responsabili dell'assistenza fiscale da individuare tra gli iscritti nell'albo dei dottori commercialisti o in quello dei ragionieri liberi professionisti, anche assunti con rapporto di lavoro subordinato.

3. I centri svolgono attivita' di assistenza fiscale previa autorizzazione del Ministero delle finanze.

))

### Art. 34. - (Attivita').

1. I centri costituiti dai soggetti di cui alle lettere a), b) e c) del comma l dell'articolo 32 prestano l'assistenza fiscale alle imprese. Sono escluse dall'assistenza fiscale le imprese soggette all'imposta sul reddito delle persone giuridiche tenute alla nomina del collegio sindacale, nonche' quelle alle quali non sono applicabili le disposizioni concernenti gli studi di settore diverse dalle societa' cooperative e loro consorzi che, unitamente ai propri soci, fanno riferimento alle associazioni nazionali riconosciute in base al decreto legislativo del Capo provvisorio dello Stato 14 dicembre 1947, n. 1577.

2. I centri costituiti dai soggetti di cui alle lettere d), e) e f) del comma l dell'articolo 32 prestano l'assistenza fiscale nei confronti dei contribuenti non titolari di redditi di lavoro autonomo e d'impresa di cui agli articoli 49, comma 1, e 51 del testo unico delle imposte sui redditi, approvato con decreto del Presidente della Repubblica 22 dicembre 1986, n. 917.

3. I centri prestano assistenza fiscale ai contribuenti che la richiedono e, in particolare:

- a) elaborano e predispongono le dichiarazioni tributarie, nonche' curano gli ulteriori adempimenti tributari;
- b) redigono le scritture contabili;
- c) verificano la conformita' dei dati esposti nelle dichiarazioni alla relativa documentazione;
- d) consegnano al contribuente copia della dichiarazione elaborata e del prospetto di liquidazione delle imposte;
- e) comunicano ai sostituti d'imposta il risultato finale delle dichiarazioni stesse, ai fini del conguaglio a credito o a debito in sede di ritenuta d'acconto;
- f) inviano all'amministrazione finanziaria le dichiarazioni dei redditi e le scelte ai fini della destinazione dell'otto e del quattro per mille dell'imposta sul reddito delle persone fisiche.

4. In relazione alla dichiarazione annuale dei redditi dei titolari dei redditi di lavoro dipendente e assimilati indicati agli articoli 46 e 47, comma 1, lettere a), d), g), con esclusione delle indennita' percepite dai membri del Parlamento europeo, e l) del testo unico delle imposte sui redditi approvato con decreto del Presidente della Repubblica 22 dicembre 1986, n. 917, nonche' dei redditi indicati all'articolo 49, comma 2, lettera a), del medesimo testo unico, i centri costituiti dai soggetti di cui alle lettere d), e) e f) del comma 1 dell'articolo 32, svolgono le attivita' di cui alle lettere da c) a f) del comma 3 ((assicurando adeguati livelli di servizio. Con provvedimento del direttore dell'Agenzia delle entrate sono definiti i livelli di servizio anche in relazione agli esiti dell'assistenza fiscale e le relative modalita' di misurazione.))

### Art. 35. - (( (Responsabili dei centri). ))

((

1. Il responsabile dell'assistenza fiscale dei centri costituiti dai soggetti di cui all'articolo 32, comma 1, lettere a), b) e c), su richiesta del contribuente:

- a) rilascia un visto di conformita' dei dati delle dichiarazioni predisposte dal centro, alla relativa documentazione e alle risultanze delle scritture contabili, nonche' di queste ultime alla relativa documentazione contabile;
- b) assevera che gli elementi contabili ed extracontabili comunicati all'amministrazione finanziaria e rilevanti ai fini dell'applicazione degli studi di settore corrispondono a quelli risultanti dalle scritture contabili e da altra documentazione idonea.

2. Il responsabile dell'assistenza fiscale dei centri costituiti dai soggetti di cui all'articolo 32, comma 1, lettere d), e) e f):

- a) rilascia, su richiesta del contribuente, un visto di conformita' dei dati delle dichiarazioni unificate alla relativa documentazione;
- b) rilascia, a seguito della attivita' di cui alla lettera c) del comma 3 dell'articolo 34, un visto di conformita' dei dati esposti nelle dichiarazioni alla relativa documentazione.

3. I soggetti indicati alle lettere a) e b), del comma 3 dell'articolo 3 del decreto del Presidente della Repubblica 22 luglio 1998, n. 322, abilitati alla trasmissione telematica delle dichiarazioni, rilasciano, su richiesta dei contribuenti, il visto di conformita' e l'asseverazione di cui ai commi 1 e 2, lettera a), del presente articolo relativamente alle dichiarazioni da loro predisposte.

))

### Art. 36. - (( (Certificazione tributaria). ))

((

1. I revisori contabili iscritti negli albi dei dottori commercialisti, dei ragionieri e periti commerciali e dei consulenti del lavoro che hanno esercitato la professione per almeno cinque anni possono effettuare, ai soli fini fiscali, la certificazione di cui al comma 2 nei riguardi dei contribuenti titolari di redditi d'impresa in regime di contabilita' ordinaria, anche per opzione, sempreche' hanno tenuto le scritture contabili dei contribuenti stessi nel corso del periodo d'imposta cui si riferisce la certificazione.

2. La certificazione tributaria puo' essere rilasciata a condizione che nei confronti del medesimo contribuente siano stati altresi' rilasciati il visto di conformita' di cui all'articolo 35, comma 1, lettera a), e, qualora siano applicabili le disposizioni concernenti gli studi di settore, l'asseverazione di cui alla lettera b) dello stesso comma 1 dell'articolo 35 e il soggetto incaricato abbia accertato l'esatta applicazione delle norme tributarie sostanziali ed eseguito gli adempimenti, i controlli e le attivita' indicati annualmente con decreto del Ministro delle finanze.

3. Per le dichiarazioni relative a periodi di imposta per i quali e' stata rilasciata una certificazione tributaria regolare:

- a) non sono applicabili le disposizioni di cui agli articoli 39, secondo comma, del decreto del Presidente della Repubblica 29 settembre 1973, n. 600, e 55 del decreto del Presidente della Repubblica 26 ottobre 1972, n. 633, in materia di accertamenti induttivi;
- b) gli accertamenti basati sugli studi di settore di cui all'articolo 10 della legge 8 maggio 1998, n. 146, sono notificati, a pena di decadenza, entro il 31 dicembre del terzo anno successivo a quello in cui le dichiarazioni sono state presentate;
- c) in caso di ricorso contro l'atto di accertamento, le imposte o le maggiori imposte, unitamente ai relativi interessi e alle sanzioni, sono iscritte a ruolo secondo i criteri di cui all'articolo 68, del decreto legislativo 31 dicembre 1992, n. 546, ed all'articolo 19 del decreto legislativo 18 dicembre 1997, n. 472, concernenti, rispettivamente il pagamento dei tributi e delle sanzioni amministrative tributarie in pendenza di giudizio, dopo la sentenza della commissione tributaria provinciale. Restano, comunque, fermi i criteri indicati nell'articolo 15 del decreto del Presidente della Repubblica 29 settembre 1973, n. 602, se la rettifica riguarda esclusivamente redditi non oggetto della certificazione tributaria.

))

### Art. 37. - (Assistenza fiscale prestata dai sostituti d'imposta).

1. I sostituti d'imposta che erogano i redditi di cui agli articoli 46 e 47, comma 1, lettere a), d), g), con esclusione delle indennita' percepite dai membri del parlamento europeo, e l), del testo unico delle imposte sui redditi, approvato con il decreto del Presidente della Repubblica 22 dicembre 1986, n. 917, possono prestare assistenza fiscale nei confronti dei propri sostituiti.

2. I sostituti di cui al comma 1 che prestano assistenza fiscale:

- a) ricevono le dichiarazioni e le schede per la scelta della destinazione del quattro e dell'otto per mille dell'imposta sul reddito delle persone fisiche;
- b) elaborano le dichiarazioni;
- c) consegnano al contribuente copia della dichiarazione elaborata e del prospetto di liquidazione delle imposte;
- d) effettuano le operazioni di conguaglio da eseguire con le modalita' di cui al comma 7;
- e) inviano le dichiarazioni dei redditi e le suddette scelte.

2-bis. I sostituti d'imposta che comunicano ai propri sostituiti, entro il 15 gennaio di ogni anno, di voler prestare assistenza fiscale provvedono a:

- a) controllare, sulla base dei dati ed elementi direttamente desumibili dalla dichiarazione presentata dal sostituito, la regolarita' formale della stessa anche in relazione alle disposizioni che stabiliscono limiti alla deducibilita' degli oneri, alle detrazioni ed ai crediti di imposta;
- b) consegnare al sostituito, prima della trasmissione della dichiarazione, copia della dichiarazione elaborata ed il relativo prospetto di liquidazione;
- c) trasmettere in via telematica all'Agenzia delle entrate le dichiarazioni elaborate e i relativi prospetti di liquidazione((e consegnare le buste contenenti le schede relative alle scelte per la destinazione dell'otto, del cinque e del due per mille dell'imposta sul reddito delle persone fisiche, secondo le modalita' stabilite con uno o piu' provvedimenti del direttore dell'Agenzia delle entrate)), entro: 1) il 15 giugno di ciascun anno, per le dichiarazioni presentate dal contribuente entro il 31 maggio; 2) il 29 giugno di ciascun anno, per le dichiarazioni presentate dal contribuente dal 1° al 20 giugno; 3) il 23 luglio di ciascun anno, per le dichiarazioni presentate dal contribuente dal 21 giugno al 15 luglio; 4) il 15 settembre di ciascun anno, per le dichiarazioni presentate dal contribuente dal 16 luglio al 31 agosto; 5) il 30 settembre di ciascun anno, per le dichiarazioni presentate dal contribuente dal 1° al 30 settembre; (51)
- c-bis) ((LETTERA ABROGATA DAL D.L. 18 OTTOBRE 2023, N. 145, CONVERTITO CON MODIFICAZIONI DALLA L. 15 DICEMBRE 2023, N. 191));
- d) comunicare all'Agenzia delle entrate in via telematica, entro i termini previsti alla lettera c), il risultato finale delle dichiarazioni. Si applicano, ove compatibili, le disposizioni di cui all'articolo 16, comma 4-bis, del decreto del Ministro delle finanze 31 maggio 1999, n. 164;
- e) conservare copia delle dichiarazioni e dei relativi prospetti di liquidazione fino al 31 dicembre del secondo anno successivo a quello di presentazione ((...)).(51)

3. I sostituti che non prestano assistenza fiscale consentono in ogni caso ai centri l'attivita' di raccolta degli atti e documenti necessari per l'attivita' di cui alle lettere da c) a f) del comma 3 dell'articolo 34.

4. I sostituti d'imposta tengono conto del risultato contabile delle dichiarazioni dei redditi elaborate dai centri. Il debito, per saldo e acconto, o il credito risultante dai prospetti di liquidazione delle imposte e' rispettivamente aggiunto o detratto a carico delle ritenute d'acconto relative al periodo d'imposta in corso al momento della presentazione della dichiarazione.

--------------- AGGIORNAMENTO (51) Il D.L. 21 giugno 2022, n. 73, convertito con modificazioni dalla L. 4 agosto 2022, n. 122, ha disposto (con l'art. 2, comma 2) che le presenti modifiche si applicano a partire dalle dichiarazioni relative al periodo d'imposta in corso alla data di entrata in vigore del suddetto decreto.

### Art. 38. - Compensi

1. Per le attivita' di cui al comma 4 dell'articolo 34, ai centri e, a decorrere dall'anno 2006, agli iscritti nell'Albo dei dottori commercialisti e degli esperti contabili di cui all'articolo 1, comma 4, e all'articolo 78 del decreto legislativo 28 giugno 2005, n. 139, e nell'albo dei consulenti del lavoro di cui alla legge 11 gennaio 1979, n. 12, spetta un compenso, a carico del bilancio dello Stato, di euro 14 per ciascuna dichiarazione elaborata e trasmessa e di euro 26 per l'elaborazione e la trasmissione delle dichiarazioni in forma congiunta. Le modalita' di corresponsione dei compensi sono stabilite con decreto del Ministero delle finanze, di concerto con il Ministero del tesoro, del bilancio e della programmazione economica. (15) (17) (18) (19) (20) (21) (24) (25) (28) (31) (33) (34)

2. ((PERIODO SOPPRESSO DAL D.LGS. 21 NOVEMBRE 2014, N. 175)). Nessun compenso spetta ai sostituti per le attivita' di cui al comma 4 del predetto articolo 37. I predetti compensi non costituiscono corrispettivi agli effetti dell'imposta sul valore aggiunto. (15) (17) (18) (19) (20) (21) (24) (25) (28) (31) (33)

3. La misura dei compensi previsti nel presente articolo e' adeguata ogni anno, con decreto del Ministero delle finanze, di concerto con il Ministero del tesoro, del bilancio e della programmazione economica, con l'applicazione di una percentuale pari alla variazione dell'indice dei prezzi al consumo per le famiglie di operai e di impiegati accertata dall'Istat, rilevata nell'anno precedente.

-------------- AGGIORNAMENTO (15) Il Decreto 1 agosto 2001 (in G.U. 3/11/2001, n. 256) ha disposto (con l'art. 1, comma 1) che "Il compenso di L. 25.000 spettante, ai sensi dell'art. 38, comma 1, del decreto legislativo 9 luglio 1997, n. 241, ai centri di assistenza fiscale, per ciascuna dichiarazione modello 730/2000 elaborata e trasmessa, e' elevato, ai sensi del comma 3 del citato art. 38, a L. 25.650". Ha inoltre disposto (con l'art. 1, comma 2) che "Il compenso di L. 20.000 spettante, ai sensi dell'art. 38, comma 2, del decreto legislativo 9 luglio 1997, n. 241, ai sostituti d'imposta per ciascuna dichiarazione modello 730/2000 elaborata e trasmessa, e' elevato, ai sensi del comma 3 del citato art. 38, a L. 20.520". -------------- AGGIORNAMENTO (17) IL Decreto 26 novembre 2002 (in G.U. 21/01/2003, n. 16) ha disposto (con l'art. 1, comma 1) che "Il compenso di Euro 13,25 spettante, ai sensi dell'art. 38, comma 1, del decreto legislativo 9 luglio 1997, n. 241, ai centri di assistenza fiscale, per ciascuna dichiarazione modello 730/2001 elaborata e trasmessa, e' elevato, ai sensi del comma 3 del citato art. 38, a Euro 13,61". Ha inoltre disposto (con l'art. 1, comma 2) che "Il compenso di Euro 10,60 spettante, ai sensi dell'art. 38, comma 2, del decreto legislativo 9 luglio 1997, n. 241, ai sostituti d'imposta per ciascuna dichiarazione modello 730/2001 elaborata e trasmessa e' elevato, ai sensi del comma 3 del citato art. 38 a Euro 10,89". -------------- AGGIORNAMENTO (18) Il Decreto 24 giugno 2003 (in G.U. 26/08/2003, n. 197) ha disposto (con l'art. 1, comma 1) che "Il compenso di Euro 13,61 spettante, ai sensi dell'art. 38, comma 1, del decreto legislativo 9 luglio 1997, n. 241, ai Centri di assistenza fiscale, per ciascuna dichiarazione modello 730/2002 elaborata e trasmessa, e' elevato, ai sensi del comma 3 del citato art. 38, a Euro 13,98". Ha inoltre disposto (con l'art.1, comma 2) che "Il compenso di Euro 10,89 spettante, ai sensi dell'art. 38, comma 2, del decreto legislativo 9 luglio 1997, n. 241, ai sostituti d'imposta per ciascuna dichiarazione modello 730/2002 elaborata e trasmessa, e' elevato, ai sensi del comma 3 del citato art. 38, a Euro 11,18". -------------- AGGIORNAMENTO (19) Il Decreto 6 maggio 2004 (in G.U. 23 luglio 2004, n. 171) ha disposto (con l'art. 1, comma 1) che "Il compenso di Euro 13,98 spettante, ai sensi dell'art. 38, comma 1, del decreto legislativo 9 luglio 1997, n. 241, ai centri di assistenza fiscale, per ciascuna dichiarazione modello 730/2003 elaborata e trasmessa, e' elevato, ai sensi del comma 3 del citato art. 38, a Euro 14,33". Ha inoltre disposto (con l'art. 1, comma 2) che "Il compenso di Euro 11,18 spettante, ai sensi dell'art. 38, comma 2, del decreto legislativo 9 luglio 1997, n. 241, ai sostituti d'imposta per ciascuna dichiarazione modello 730/2003 elaborata e trasmessa, e' elevato, ai sensi del comma 3 del citato art. 38, a Euro 11,46". --------------- AGGIORNAMENTO (20) Il Decreto 24 marzo 2005 (in G.U. 17/05/2005, n. 113) ha disposto (con l'art. 1, comma 1) che "Il compenso di Euro 14,33 spettante, ai sensi dell'art. 38, comma 1, del decreto legislativo 9 luglio 1997, n. 241, ai Centri di assistenza fiscale, per ciascuna dichiarazione modello 730/2004 elaborata e trasmessa, e' elevato, ai sensi del comma 3 del citato art. 38, a Euro 14,62". Ha inoltre disposto (con l'art. 1, comma 2) che "Il compenso di Euro 11,46 spettante, ai sensi dell'art. 38, comma 2, del decreto legislativo 9 luglio 1997, n. 241, ai sostituti d'imposta per ciascuna dichiarazione modello 730/2004 elaborata e trasmessa, e' elevato, ai sensi del comma 3 del citato art. 38, a Euro 11,69". --------------- AGGIORNAMENTO (21) Il Decreto 19 aprile 2006 (in G.U. 20/06/2006, n. 141) ha disposto (con l'art. 1, comma 1) che "Il compenso di Euro 14,62 spettante, ai sensi dell'art. 38, comma 1, del decreto legislativo 9 luglio 1997, n. 241, ai Centri di assistenza fiscale, per ciascuna dichiarazione modello 730/2005 elaborata e trasmessa, e' elevato, ai sensi del comma 3 del citato art. 38, a Euro 14,87". Ha inoltre disposto (con l'art. 1, comma 2) che "Il compenso di Euro 11,69 spettante, ai sensi dell'art. 38, comma 2, del decreto legislativo 9 luglio 1997, n. 241, ai sostituti d'imposta per ciascuna dichiarazione modello 730/2005 elaborata e trasmessa, e' elevato, ai sensi del comma 3 del citato art. 38, a Euro 11,89". --------------- AGGIORNAMENTO (24) Il Decreto 21 maggio 2007 (in G.U. 09/07/2007, n. 157) ha disposto (con l'art. 1, comma 1) che "Il compenso di Euro 14,87 spettante, ai sensi dell'art. 38, comma 1, del decreto legislativo 9 luglio 1997, n. 241, ai C.A.F. e ai professionisti abilitati, per ciascuna dichiarazione modello 730/2006 elaborata e trasmessa, e' elevato, ai sensi del comma 3 del citato art. 38, a Euro 15,17". Ha inoltre disposto (con l'art. 1, comma 2) che "Il compenso di Euro 11,89 spettante, ai sensi dell'art. 38, comma 2, del decreto legislativo 9 luglio 1997, n. 241, ai sostituti d'imposta per ciascuna dichiarazione modello 730/2006 elaborata e trasmessa, e' elevato, ai sensi del comma 3 del citato art. 38, a Euro 12,13". --------------- AGGIORNAMENTO (28) Il Decreto 13 maggio 2009 (in G.U. 18/09/2009, n. 217) ha disposto (con l'art. 1, comma 1) che "Il compenso di cui all'art. 38, comma 1, del decreto legislativo 9 luglio 1997, n. 241 adeguato per l'anno 2007 a 15,43 con decreto ministeriale del 15 aprile 2008, spettante ai C.A.F. e ai professionisti abilitati, per ciascuna dichiarazione modello 730/2008 elaborata e trasmessa, e' elevato, ai sensi del comma 3 del citato art. 38, a 15,92." Ha inoltre disposto (con l'art. 1, comma 2) che "Il compenso di cui all'art. 38, comma 2, del decreto legislativo 9 luglio 1997, n. 241 adeguato per l'anno 2007 a 12,34 con decreto ministeriale del 15 aprile 2008, spettante ai sostituti d'imposta per ciascuna dichiarazione modello 730/2008 elaborata e trasmessa, e' elevato, ai sensi del comma 3 del citato art. 38, a 12,73." --------------- AGGIORNAMENTO (31) IL Decreto 5 agosto 2010 (in G.U. 13/09/2010, n. 214) ha disposto (con l'art. 1, comma 1) che "Il compenso di cui all'art. 38, comma 1, del decreto legislativo 9 luglio 1997, n. 241 adeguato per l'anno 2008 a €15,92 con decreto ministeriale del 13 maggio 2009, spettante ai C.A.F. e ai professionisti abilitati, per ciascuna dichiarazione modello 730/2009 elaborata e trasmessa, e' elevato, ai sensi del comma 3 del citato art. 38, a € 16,03". Ha inoltre disposto (con l'art. 1, comma 2) che "Il compenso di cui all'art. 38, comma 2, del decreto legislativo 9 luglio 1997, n. 241 adeguato per l'anno 2008 a € 12,73 con decreto ministeriale del 13 maggio 2009, spettante ai sostituti d'imposta per ciascuna dichiarazione modello 730/2009 elaborata e trasmessa, e' elevato, ai sensi del comma 3 del citato art. 38, a €12,82". --------------- AGGIORNAMENTO (33) IL Decreto 14 giugno 2011 (in G.U. 12/09/2011, n. 212) ha disposto (con l'art. 1, comma 1) che "Il compenso di cui all'articolo 38, comma 1, del decreto legislativo 9 luglio 1997, n. 241 adeguato per l'anno 2009 a € 16,03 con decreto ministeriale del 5 agosto 2010, spettante ai C.A.F. e ai professionisti abilitati, per ciascuna dichiarazione modello 730/2010 elaborata e trasmessa, e' elevato, ai sensi del comma 3 del citato articolo 38, a € 16,29". Ha inoltre disposto (con l'art. 1, comma 2) che "11 compenso di cui all'articolo 38, comma 2, del decreto legislativo 9 luglio 1997, n. 241 adeguato per l'anno 2009 a € 12,82 con decreto ministeriale del 5 agosto 2010, spettante ai sostituti d'imposta per ciascuna dichiarazione modello 730/2010 elaborata e trasmessa, e' elevato, ai sensi del comma 3 del citato articolo 38, a € 13,03". --------------- AGGIORNAMENTO (34) La L. 12 novembre 2011, n. 183, ha disposto (con l'art. 4, comma 35) che "le disposizioni di cui ai commi da 30 a 34 si applicano con riferimento alle attivita' svolte a decorrere dall'anno 2012".

### Art. 39. - (Sanzioni).

1. Salvo che il fatto costituisca reato e ferma restando l'irrogazione delle sanzioni per le violazioni di norme tributarie: ((a) ai soggetti indicati nell'articolo 35 che rilasciano il visto di conformita', ovvero l'asseverazione, infedele si applica la sanzione amministrativa da euro 258 ad euro 2.582. Se il visto infedele e' relativo alla dichiarazione dei redditi presentata con le modalita' di cui all'articolo 13 del regolamento di cui al decreto del Ministro delle finanze 31 maggio 1999, n. 164, non si applica la sanzione di cui al periodo precedente e i soggetti di cui all'articolo 35 sono tenuti al pagamento di una somma pari al 30 per cento della maggiore imposta riscontrata, sempre che il visto infedele non sia stato indotto dalla condotta dolosa o gravemente colposa del contribuente. Costituiscono titolo per la riscossione mediante ruolo di cui al decreto del Presidente della Repubblica 29 settembre 1973, n. 602, le comunicazioni con le quali sono richieste le somme di cui al periodo precedente. Eventuali controversie sono devolute alla giurisdizione tributaria. Sempreche' l'infedelta' del visto non sia gia' stata contestata con la comunicazione di cui all'articolo 26, comma 3-ter, del regolamento di cui al decreto del Ministro delle finanze 31 maggio 1999, n. 164, il Centro di assistenza fiscale o il professionista puo' trasmettere una dichiarazione rettificativa del contribuente, ovvero, se il contribuente non intende presentare la nuova dichiarazione, puo' trasmettere una comunicazione dei dati relativi alla rettifica il cui contenuto e' definito con provvedimento del direttore dell'Agenzia delle entrate. In tal caso la somma dovuta e' ridotta ai sensi dell'articolo 13 del decreto legislativo 18 dicembre 1997, n. 472. La violazione e' punibile in caso di liquidazione delle imposte, dei contributi, dei premi e dei rimborsi dovuti in base alle dichiarazioni, di cui all'articolo 36-bis del decreto del Presidente della Repubblica 29 settembre 1973, n. 600, e in caso di controllo ai sensi degli articoli 36-ter e seguenti del medesimo decreto, nonche' in caso di liquidazione dell'imposta dovuta in base alle dichiarazioni e in caso di controllo di cui agli articoli 54 e seguenti del decreto del Presidente della Repubblica 26 ottobre 1972, n. 633. La violazione e' punibile a condizione che non trovi applicazione l'articolo 12-bis del decreto del Presidente della Repubblica 29 settembre 1973, n. 602. In caso di ripetute violazioni, ovvero di violazioni particolarmente gravi, e' disposta a carico dei predetti soggetti la sospensione dalla facolta' di rilasciare il visto di conformita' e l'asseverazione, per un periodo da uno a tre anni. In caso di ripetute violazioni commesse successivamente al periodo di sospensione, e' disposta l'inibizione dalla facolta' di rilasciare il visto di conformita' e l'asseverazione. Si considera violazione particolarmente grave il mancato pagamento della suddetta sanzione. Le sanzioni di cui al presente comma non sono oggetto della maggiorazione prevista dall'articolo 7, comma 3, del decreto legislativo 18 dicembre 1997, n. 472)); a-bis) ((LETTERA ABROGATA DAL D.L. 28 GENNAIO 2019, N.4, CONVERTITO CON MODIFICAZIONI DALLA L. 28 MARZO 2019, N. 26)); a-ter) ((LETTERA ABROGATA DAL D.L. 28 GENNAIO 2019, N.4, CONVERTITO CON MODIFICAZIONI DALLA L. 28 MARZO 2019, N. 26)). b) al professionista che rilascia una certificazione tributaria di cui all'articolo 36 infedele, si applica la sanzione amministrativa da euro 516 ad euro 5.165. In caso di accertamento di tre distinte violazioni commesse nel corso di un biennio, e' disposta la sospensione dalla facolta' di rilasciare la certificazione tributaria per un periodo da uno a tre anni. La medesima facolta' e' inibita in caso di accertamento di ulteriori violazioni ovvero di violazioni di particolare gravita'; si considera violazione particolarmente grave il mancato pagamento della suddetta sanzione. (16)

1-bis. Nei casi di violazioni commesse ai sensi dei commi 1 e 3 del presente articolo e dell'articolo 7-bis, si applicano, in quanto compatibili, le disposizioni del decreto legislativo 18 dicembre 1997, n. 472. Il centro di assistenza fiscale per il quale abbia operato il trasgressore e' obbligato solidalmente con il trasgressore stesso al pagamento di un importo pari alla sanzione irrogata e alle altre somme indicate al comma 1.

2. Le violazioni dei commi 1 e 3 del presente articolo e dell'articolo 7-bis sono contestate e le relative sanzioni sono irrogate dalla direzione regionale dell'Agenzia delle entrate competente in ragione del domicilio fiscale del trasgressore anche sulla base delle segnalazioni inviate dagli uffici locali della medesima Agenzia. L'atto di contestazione e' unico per ciascun anno solare di riferimento e, fino al compimento dei termini di decadenza, puo' essere integrato o modificato dalla medesima direzione regionale. I provvedimenti ivi previsti sono trasmessi agli ordini di appartenenza dei soggetti che hanno commesso la violazione per l'eventuale adozione di ulteriori provvedimenti.

3. In caso di inosservanza delle disposizioni di cui all'articolo 37, commi 2 e 4, ai sostituti di imposta si applica la sanzione amministrativa da euro 258 a euro 2.582. (16)

4. L'autorizzazione all'esercizio dell'attivita' di assistenza fiscale di cui all'articolo 33, comma 3, e' sospesa, per un periodo da tre a dodici mesi, quando sono commesse gravi e ripetute violazioni di norme tributarie o contributive e delle disposizioni di cui agli articoli 34 e 35, nonche' quando gli elementi forniti all'amministrazione finanziaria risultano falsi o incompleti rispetto alla documentazione fornita dal contribuente. In caso di ripetute violazioni, ovvero di violazioni particolarmente gravi, e' disposta la revoca dell'esercizio dell'attivita' di assistenza; nei casi di particolare gravita' e' disposta la sospensione cautelare.

4-bis. La definizione agevolata delle sanzioni ai sensi dell'articolo 16, comma 3, del decreto legislativo 18 dicembre 1997, n. 472, non impedisce l'applicazione della sospensione, dell'inibizione e della revoca.

4-ter. Il mancato rispetto di adeguati livelli di servizio comporta l'applicazione della sanzione da 516 a 5.165 euro.

--------------- AGGIORNAMENTO (16) La L. 27 dicembre 2006, n. 296 ha disposto (con l'art. 1, comma 34) che "Per le violazioni di cui all'articolo 7-bis e ai commi 1 e 3 dell'articolo 39 del decreto legislativo 9 luglio 1997, n. 241, e successive modificazioni, ferma restando l'applicazione dell' articolo 3, comma 3, del decreto legislativo 18 dicembre 1997, n. 472, nelle ipotesi in cui la violazione sia stata gia' contestata alla data di entrata in vigore della presente legge, non si da' luogo a restituzione di quanto eventualmente pagato." --------------- AGGIORNAMENTO (28) Il D.Lgs. 24 settembre 2015, n. 158, ha disposto (con l'art. 32, comma 1) che la presente modifica si applica a decorrere dal 1 gennaio 2017. --------------- AGGIORNAMENTO (29) Il D.Lgs. 24 settembre 2015, n. 158 come modificato dalla L. 28 dicembre 2015, n. 208 ha disposto (con l'art. 32, comma 1) che la presente modifica si applica a decorrere dal 1 gennaio 2016.

### Art. 40. - (( (Disposizioni di attuazione). ))

((

1. Il Ministro delle finanze, con regolamenti adottati ai sensi dell'articolo 17, comma 3, della legge 23 agosto 1988, n. 400, stabilisce:

- a) i criteri e le condizioni per il rilascio ai centri dell'autorizzazione all'esercizio delle attivita' di cui all'articolo 34, per la loro iscrizione in apposito albo e per il trasferimento delle quote o delle azioni, che deve in ogni caso essere posto in essere tra i soggetti autorizzati alla costituzione dei centri stessi, i poteri divigilanza, anche ispettiva, dell'amministrazione finanziaria;
- b) le modalita' per l'esecuzione dei controlli e l'erogazione dei rimborsi per i contribuenti nei cui confronti e' stato rilasciato il visto e l'asseverazione di cui ai commi 1 e 2 dell'articolo 35, ovvero e' stata effettuata la certificazione ai sensi dell'articolo 36, tenendo conto, in particolare, del tipo di assistenza fiscale prestata ai predetti contribuenti anche in ordine alla tenuta delle scritture contabili;
- c) la prestazione di congrue garanzie per i danni ai contribuenti in relazione al rilascio del visto di conformita', dell'asseverazione e della certificazione tributaria secondo le disposizioni del presente capo commisurate anche al numero dei contribuenti assistiti;
- d) ulteriori disposizioni attuative di quanto previsto nel presente capo.

))

